regions = [
    {
        "country": "DZ",
        "name": "Algiers",
    },
    {
        "country": "DZ",
        "name": "Béjaïa",
    },
    {
        "country": "DZ",
        "name": "Chlef Province",
        "subregions": [
            {
                "name": "Dahra",
            }
        ],
    },
    {
        "country": "DZ",
        "name": "Mascara",
    },
    {
        "country": "DZ",
        "name": "Médéa",
    },
    {
        "country": "DZ",
        "name": "Tlemcen",
    },
    {
        "country": "DZ",
        "name": "Zaccar",
    },
    {
        "country": "CV",
        "name": "Chã das Caldeiras",
    },
    {
        "country": "MA",
        "name": "Atlas Mountains",
    },
    {
        "country": "MA",
        "name": "Benslimane",
    },
    {
        "country": "MA",
        "name": "Meknès",
    },
    {
        "country": "ZA",
        "name": "Western Cape",
        "subregions": [
            {"name": "Breede River Valley"},
            {"name": "Cape South Coast"},
            {"name": "Olifants River"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The vineyards of South Africa are mostly located in the Western Cape, near the coast. Rainfall on the coastal side measures up to 1000 mm per year, making it possible for vine to thrive. There are five regions in the geographical unit of the Western Cape – Breede River Valley, Cape South Coast, Coastal Region, Klein Karoo and Olifants River. ",
        },
    },
    {
        "country": "ZA",
        "name": "Little Karoo",
        "synonyms": ["Klein Karoo"],
        "subregions": [
            {"name": "Calitzdorp"},
            {"name": "Langeberg-Garcia"},
        ],
    },
    {
        "country": "ZA",
        "name": "Coastal Region",
        "subregions": [
            {"name": "Swartland"},
            {"name": "Tulbagh"},
            {"name": "Constantia"},
            {"name": "Stellenbosch"},
            {"name": "Paarl"},
            {"name": "Darling"},
            {"name": "Cape Point"},
            {"name": "Wellington"},
        ],
    },
    {
        "country": "ZA",
        "name": "Durbanville",
    },
    {
        "country": "ZA",
        "name": "Elim",
    },
    {
        "country": "ZA",
        "name": "Franschhoek",
    },
    {
        "country": "ZA",
        "name": "Orange River Valley",
    },
    {
        "country": "ZA",
        "name": "Cederberg",
    },
    {
        "country": "ZA",
        "name": "Piekenierskloof",
    },
    {
        "country": "TN",
        "name": "Arianah",
    },
    {
        "country": "TN",
        "name": "Nabul",
    },
    {
        "country": "TN",
        "name": "Sousse",
    },
    {
        "country": "AR",
        "name": "Buenos Aires Province",
        "subregions": [
            {
                "name": "Médanos",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "Catamarca Province",
        "synonyms": ["Catamarca"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "La Rioja Province",
        "synonyms": ["La Rioja"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "Mendoza",
        "synonyms": ["Mendoza Province"],
        "subregions": [
            {"name": "Agrelo"},
            {"name": "Barrancas"},
            {"name": "Las Compuertas"},
            {"name": "Lujan de Cuyo"},
            {"name": "Lunlunta"},
            {"name": "Maipu"},
            {"name": "Perdriel"},
            {"name": "San Martin"},
            {"name": "San Rafael"},
            {
                "name": "Uco Valley",
                "subregions": [
                    {"name": "Altamira"},
                    {"name": "La Consulta"},
                    {"name": "Los Chacayes"},
                    {
                        "name": "San Carlos",
                        "subregions": [
                            {"name": "Pampa El Cepillo"}
                        ]
                    },
                    {
                        "name": "Tunuyan",
                        "subregions": [
                            {"name": "San Pablo"}
                        ]
                    },
                    {
                        "name": "Tupungato",
                        "subregions": [
                            {"name": "Gualtallary"}
                        ]
                    },
                    {"name": "Vista Flores"}
                ]
            },
            {"name": "Ugarteche"},
            {"name": "Vistalba"}
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "Neuquén Province",
        "synonyms": ["Neuquén"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "Río Negro Province",
        "synonyms": ["Río Negro"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "Salta Province",
        "synonyms": ["Salta"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "AR",
        "name": "San Juan Province",
        "synonyms": ["San Juan"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Argentina is the world’s fifth largest wine producer in the world with just under 200,000 hectares of vines and the tenth largest wine exporter. The country’s vineyards are mostly confined to the western sector of the country, in the plains and foothills near the Andes. In the rain shadow of the Andes, Argentina’s wine producing regions are very dry, a condition exacerbated by the Zonda, a fierce, dusty, hot afternoon wind that blows down from the mountains in the late spring and early summer. The general lack of humidity in most Argentinean winegrowing regions keeps vineyards free of fungal problems, and snowmelt provides plentiful water for irrigation—in those years that the Andes receive heavy winter snowfall. Vineyards are planted at high altitude to help mitigate the semi-deserted climate that prevail in most of the country. In fact, the average national elevation for vineyards is approximately 900 meters above sea level and can reach over 3000 meters in the norther region of Salta. Mendoza is the biggest centre of production, representing over 70% of the country’s wine production. Malbec is by far the most planted grape in the country representing nearly 25% of the total grapevine plantings. ",
        },
    },
    {
        "country": "BO",
        "name": "Tarija Department",
        "synonyms": ["Tarija"],
    },
    {
        "country": "BR",
        "name": "Bahia",
        "subregions": [
            {"name": "Curaçá"},
            {"name": "Irecê"},
            {"name": "Juazeiro"},
        ],
    },
    {
        "country": "BR",
        "name": "Mato Grosso",
        "subregions": [
            {
                "name": "Nova Mutum",
            }
        ],
    },
    {
        "country": "BR",
        "name": "Minas Gerais",
        "subregions": [
            {"name": "Andradas"},
            {"name": "Caldas"},
            {"name": "Pirapora"},
            {"name": "Santa Rita de Caldas"},
        ],
    },
    {
        "country": "BR",
        "name": "Paraná",
        "subregions": [
            {"name": "Bandeirantes"},
            {"name": "Marialva"},
            {"name": "Maringá"},
            {"name": "Rosário do Avaí"},
        ],
    },
    {
        "country": "BR",
        "name": "Pernambuco",
        "subregions": [
            {"name": "Casa Nova"},
            {"name": "Petrolina"},
            {"name": "Santa Maria da Boa Vista"},
        ],
    },
    {
        "country": "BR",
        "name": "Rio Grande do Sul",
        "subregions": [
            {"name": "Bento Gonçalves"},
            {"name": "Caxias do Sul"},
            {"name": "Cotiporã"},
            {"name": "Farroupilha"},
            {"name": "Flores da Cunha"},
            {"name": "Garibaldi"},
            {"name": "Pinto Bandeira"},
        ],
    },
    {
        "country": "BR",
        "name": "Santa Catarina",
        "subregions": [
            {"name": "Pinheiro Preto"},
            {"name": "São Joaquim"},
            {"name": "Tangará"},
        ],
    },
    {
        "country": "BR",
        "name": "São Paulo",
        "subregions": [
            {"name": "Jundiaí"},
            {"name": "São Roque"},
        ],
    },
    {
        "country": "CA",
        "name": "British Columbia",
        "subregions": [
            {"name": "Fraser Valley"},
            {"name": "Gulf Islands"},
            {"name": "Okanagan Valley"},
            {"name": "Similkameen Valley"},
            {"name": "Thompson Valley"},
            {"name": "Vancouver Island"},
        ],
    },
    {
        "country": "CA",
        "name": "Nova Scotia",
        "subregions": [
            {
                "name": "Annapolis Valley",
            }
        ],
    },
    {
        "country": "CA",
        "name": "Ontario",
        "subregions": [
            {"name": "Lake Erie"},
            {"name": "Niagara Peninsula"},
            {"name": "Prince Edward County"},
            {"name": "Toronto"},
        ],
    },
    {
        "country": "CA",
        "name": "Quebec",
        "subregions": [
            {
                "name": "Eastern Townships",
            }
        ],
    },
    {
        "country": "CO",
        "name": "Villa de Leyva",
    },
    {
        "country": "CO",
        "name": "Valle del Cauca",
        "subregions": [
            {
                "name": "La Unión",
            }
        ],
    },
    {
        "country": "CL",
        "name": "Aconcagua",
        "subregions": [
            {"name": "Aconcagua Valley"},
            {"name": "Casablanca Valley"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "CL",
        "name": "Curicó",
        "synonyms": ["Curicó Valley"],
        "subregions": [
            { "name": "Licantén" },
            { "name": "Teno" },
            { "name": "Lontué", "synonyms": [ "Lontué Valley" ] },
        ]
    },
    {
        "country": "CL",
        "name": "Atacama",
        "subregions": [
            {"name": "Copiapó Valley"},
            {"name": "Huasco Valley"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "CL",
        "name": "Central Valley",
        "subregions": [
            {
                "name": "Rapel Valley",
                "subregions": [
                    {"name": "Cachapoal Valley"},
                    {"name": "Colchagua Valley"},
                ],
            },
            {"name": "Maipo Valley"},
            {"name": "Mataquito Valley"},
            {"name": "Maule Valley"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "CL",
        "name": "Coquimbo",
        "subregions": [
            {"name": "Choapa Valley"},
            {"name": "Elqui Valley"},
            {"name": "Limarí"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "CL",
        "name": "Pica",
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "CL",
        "name": "Southern Chile",
        "subregions": [
            {"name": "Patagonia"},
            {
                "name": "Bío-Bío Valley",
                "synonyms": ["Bío-Bío", "Valle del Bío-Bío"],
            },
            {
                "name": "Itata Valley",
                "synonyms": ["Valle del Itata"],
            },
            {
                "name": "Malleco Valley",
                "synonyms": ["Valle del Malleco"],
            },
            {
                "name": "Bueno Valley",
                "synonyms": ["Valle del Bueno"],
            },
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Chiles’ vineyards run for about 1300km, north to South, along the Pacific Ocean coastal area and most major regions of production are located to the South of the capital city, Santiago. From north to south, the six regional Denominations of Origin (DOs) in Chile are Atacama, Coquimbo, Aconcagua, the Valle Central (Central Valley), Sur (the Southern Regions), and a new area at the southernmost limit of grape growing in the country, the Austral Region. The northernmost regions of Atacama and Coquimbo are dry and desert-like, with grapes historically destined for Pisco production or the table. The country’s most suitable vineyards for fine wine are mostly situated in the Central Valley to the south of Santiago, where the proximity of the Andes cools night-time temperatures, and along the coast, where the cold, maritime Humboldt Current cools the vines. In the country’s southernmost areas of viticulture, rainfall is higher and the overall growing season is cooler and shorter. Significant variations in altitude exist in most of Chile’s major regions, as vineyard plantings climb from the coast into the Coastal Ranges, and from the valleys into the Andean foothills.",
        },
    },
    {
        "country": "MX",
        "name": "Aguascalientes",
        "subregions": [
            {
                "name": "Aguascalientes",
            }
        ],
    },
    {
        "country": "MX",
        "name": "Baja California",
        "subregions": [
            {
                "name": "Valle de Guadalupe",
                "subregions": [
                    {"name": "Valle de Calafia"},
                    {"name": "Valle de Mexicali"},
                    {"name": "Valle de San Vicente"},
                    {"name": "Valle de Santo Tomás"},
                    {"name": "Zona Tecate"},
                ],
            }
        ],
    },
    {
        "country": "MX",
        "name": "Coahuila",
        "subregions": [
            {
                "name": "Valle de Parras",
            }
        ],
    },
    {
        "country": "MX",
        "name": "Guanajuato",
        "subregions": [
            {"name": "Guanajuato City"},
            {"name": "San Miguel de Allende"},
            {"name": "Dolores Hidalgo"},
            {"name": "San Felipe"},
            {"name": "Salvatierra"},
            {"name": "San Francisco del Rincón"},
        ],
    },
    {
        "country": "MX",
        "name": "Hidalgo",
    },
    {
        "country": "MX",
        "name": "Nuevo León",
        "subregions": [
            {
                "name": "Valle de Las Maravillas",
            }
        ],
    },
    {
        "country": "MX",
        "name": "Querétaro",
        "subregions": [
            {
                "name": "Valle de Tequisquiapan",
            }
        ],
    },
    {
        "country": "MX",
        "name": "Sonora",
        "subregions": [
            {"name": "Caborca"},
            {"name": "Hermosillo"},
        ],
    },
    {
        "country": "MX",
        "name": "Zacatecas",
        "subregions": [
            {
                "name": "Valle de las Arcinas",
            }
        ],
    },
    {
        "country": "PE",
        "name": "Arequipa",
    },
    {
        "country": "PE",
        "name": "Huaral District",
    },
    {
        "country": "PE",
        "name": "Ica Region",
    },
    {
        "country": "PE",
        "name": "Pica",
    },
    {
        "country": "US",
        "name": "Arizona",
    },
    {
        "country": "US",
        "name": "California",
        "subregions": [
            {
                "name": "Central Coast",
                "subregions": [
                    {"name": "Gabilan Mountains"},
                    {
                        "name": "Monterey County",
                        "subregions": [
                            {"name": "Arroyo Seco"},
                            {"name": "Carmel Valley"},
                            {"name": "Chalone"},
                            {"name": "Hames Valley"},
                            {"name": "Monterey"},
                            {"name": "San Antonio Valley"},
                            {"name": "San Bernabe"},
                            {"name": "San Lucas"},
                            {"name": "Santa Lucia Highlands"},
                        ]
                    },
                    {
                        "name": "San Benito County",
                        "subregions": [
                            {"name": "Cienega Valley"},
                            {"name": "Lime Kiln Valley"},
                            {"name": "Mount Harlan"},
                            {"name": "Paicines"},
                            {"name": "San Benito"},
                        ]         
                    },
                    {
                        "name": "San Francisco Bay", 
                        "subregions": [
                            { "name": "Ben Lomond Mountain" },
                            { "name": "Contra Costa County" },
                            { "name": "Livermore Valley" },
                            { "name": "Pacheco Pass" },
                            { "name": "San Ysidro District" },
                            { "name": "Santa Clara Valley" },
                            { "name": "Santa Cruz Mountains" },
                        ]
                    },
                    {
                        "name": "San Luis Obispo County",
                        "subregions": [
                            {"name": "Arroyo Grande Valley"},
                            {"name": "Edna Valley"},
                            {"name": "Paso Robles"},
                            {"name": "York Mountain"},
                        ]
                    },
                    {
                        "name": "Santa Barbara County",
                        "subregions": [
                            {"name": "Alisos Canyon"},
                            {"name": "Happy Canyon of Santa Barbara", "synonyms": ["Happy Canyon"]},
                            {"name": "Santa Maria Valley"},
                            {
                                "name": "Santa Ynez Valley",
                                "subregions": [
                                    {"name": "Los Olivos District", "synonyms": ["Los Olivos"]},
                                    {"name": "Ballard Canyon"},
                                ]
                            },
                            {"name": "Sta. Rita Hills"},
                        ]
                    },
                ],
            },
            {
                "name": "Central Valley",
                "subregions": [
                    {"name": "Diablo Grande"},
                    {"name": "Fresno County", "subregions": [{"name": "Squaw Valley-Miramonte", "synonyms": ["Squaw Valley", "Miramonte"]}]},
                    {"name": "Lodi"},
                    {"name": "Madera"},
                    {"name": "River Junction"},
                    {"name": "Salado Creek"},
                    {"name": "Tracy Hills"},
                ],
            },
            {
                "name": "North Coast",
                "subregions": [
                    {
                        "name": "Humboldt County",
                        "subregions": [
                            {"name": "Willow Creek"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Lake County",
                        "subregions": [
                            {"name": "Benmore Valley"},
                            {"name": "Big Valley District"},
                            {"name": "Clear Lake"},
                            {"name": "Guenoc Valley"},
                            {"name": "High Valley"},
                            {"name": "Kelsey Bench"},
                            {"name": "Red Hills Lake County"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Marin County",
                        "subregions": [],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Mendocino County",
                        "subregions": [
                            {"name": "Anderson Valley"},
                            {"name": "Cole Ranch"},
                            {"name": "Covelo"},
                            {"name": "Dos Rios"},
                            {"name": "Eagle Peak Mendocino County"},
                            {"name": "McDowell Valley"},
                            {"name": "Mendocino"},
                            {"name": "Mendocino Ridge"},
                            {"name": "Potter Valley"},
                            {"name": "Redwood Valley"},
                            {"name": "Yorkville Highlands"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Napa County",
                        "synonyms": ["Napa"],
                        "subregions": [
                            {"name": "Napa Valley"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Petaluma Gap",
                        "subregions": [],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Solano County",
                        "synonyms": ["Solano"],
                        "subregions": [
                            {"name": "Solano County Green Valley"},
                            {"name": "Suisun Valley"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Sonoma County",
                        "synonyms": ["Sonoma"],
                        "subregions": [
                            {"name": "Alexander Valley"},
                            {"name": "Bennett Valley"},
                            {"name": "Carneros"},
                            {"name": "Chalk Hill"},
                            {"name": "Dry Creek Valley"},
                            {"name": "Fort Ross-Seaview"},
                            {"name": "Fountaingrove District"},
                            {"name": "Green Valley of Russian River Valley"},
                            {"name": "Knights Valley"},
                            {"name": "Moon Mountain District"},
                            {"name": "Northern Sonoma"},
                            {"name": "Pine Mountain-Cloverdale Peak"},
                            {"name": "Rockpile"},
                            {"name": "Russian River Valley"},
                            {"name": "Sonoma Coast"},
                            {"name": "Sonoma Mountain"},
                            {"name": "Sonoma Valley"},
                            {"name": "West Sonoma Coast"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    },
                    {
                        "name": "Trinity County",
                        "subregions": [
                            {"name": "Trinity Lakes"}
                        ],
                        "description": {"default": "", "sommelier": "", "julie": ""}
                    }

                ],
            },
            {
                "name": "Sierra Foothills",
                "subregions": [
                    {"name": "Amador County"},
                    {"name": "Calaveras County"},
                    {"name": "California Shenandoah Valley"},
                    {"name": "El Dorado"},
                    {"name": "El Dorado County"},
                    {"name": "Fair Play"},
                    {"name": "Fiddletown"},
                    {"name": "Mariposa County"},
                    {"name": "Nevada County"},
                    {"name": "North Yuba"},
                    {"name": "Placer County"},
                    {"name": "Tuolumne County"}

                ],
            },
            {
                "name": "South Coast",
                "subregions": [
                    {"name":"Antelope Valley of the California High Desert"},
                    {"name":"Cucamonga Valley"},
                    {"name":"Leona Valley"},
                    {"name":"Los Angeles County"},
                    {"name":"Malibu Coast"},
                    {"name":"Malibu-Newton Canyon"},
                    {"name":"Ramona Valley"},
                    {"name":"Saddle Rock Malibu"},
                    {"name":"San Diego County"},
                    {"name":"San Pasqual Valley"},
                    {"name":"Sierra Pelona Valley"},
                    {"name":"Tehachapi-Cummings Valley"},
                    {"name":"Temecula Valley"},
                    {"name":"Ventura County"},
                ],
            },
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Much of California well suited to grape growing with its generous sunshine, its mild winters, and its generally low humidity levels that helps prevent cryptogamic diseases. The main grape growing regions lie in the central and coastal area of the state. The region is divided into 5 large American Viticultural Areas (AVAs) : North Coast, Central Coast, South Coast, San Francisco Bay, and the Sierra Foothills. The Central Valley, which produces 75% of the state’s wine, does not have an its own official AVA. Most of the fine wine districts are located near the coast, where fog and cool sea breezes mitigate temperatures and create a large diurnal swing from warm days to cool nights. California is known for producing some varietal Chardonnay, Cabernet Sauvignon, Merlot, and Zinfandel wines. However, the list is non exhaustive and producers experiments with various varieties such as Viognier, Petite Syrah and Nebbiolo. Premium blend wines, white or red, made from classical Bordeaux grape varieties are sold as “Meritage”. ",
        },
    },
    {
        "country": "US",
        "name": "Colorado",
    },
    {
        "country": "US",
        "name": "Idaho",
    },
    {
        "country": "US",
        "name": "Michigan",
    },
    {
        "country": "US",
        "name": "Missouri",
    },
    {
        "country": "US",
        "name": "New Jersey",
    },
    {
        "country": "US",
        "name": "New Mexico",
    },
    {
        "country": "US",
        "name": "New York",
        "subregions": [
            {"name": "Finger Lakes"},
            {"name": "Hudson River Region"},
            {"name": "Long Island"},
        ],
    },
    {
        "country": "US",
        "name": "Oregon",
        "subregions": [
            {
                "name": "Willamette Valley",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Oregon is one of the most successful wine regions of the United Sates. Located to the South of Washington State, it is highly influenced by the pacific ocean. The Willamette Valley, in the North West of the regions, stretches from Portland to Eugene. It is the oldest and the largest wine area of the region, with over 2/3 of Oregon’s wineries located there. The Willamette Valley AVA encompasses eleven sub-AVAs. The regions is protected from cold Pacific Ocean air and rainstorm on the west by the Coast Range mountains. The Cascade Range to the East protects the wine regions from dry, desert-like climate. The Willamette Valley is world famous for its high quality Pinot Noir wines but is also the source of delicious Chardonnay, Pinot Gris, Pinot Blanc, Riesling, etc. South of the Willamette Valley, the Southern Oregon AVA stretches from Eugene to the Californian Border and encompasses AVAs such as the Umpqua Valley, Applegate Valley and Elkton Oregon. Climate and soil varies greatly from one area to another and so do grape varieties that include Pinot Noir, Syrah, Cabernet Sauvignon, etc.",
        },
    },
    {
        "country": "US",
        "name": "Pennsylvania",
    },
    {
        "country": "US",
        "name": "Texas",
        "subregions": [
            {"name": "Texas High Plains"},
            {"name": "Texas Hill Country"},
            {"name": "Trans-Pecos"},
        ],
    },
    {
        "country": "US",
        "name": "Virginia",
    },
    {
        "country": "US",
        "name": "Vermont",
    },
    {
        "country": "US",
        "name": "Washington",
        "subregions": [
            {
                "name": "Columbia Valley",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Despite a relatively short history of viticulture, Washington has emerged as the nation’s second largest producer of premium wines, accounting for approximately 5% of total production. Most of the state’s wine regions, and over 99% of its vineyards, are located east of the Cascade Mountains. Columbia Valley AVA is the largest appellation in the state, covering over ¼ of Washington’s landmass. Other significant AVAs include Yakima Valley, the first AVA of the state in 1983,  Walla Walla Valley and Horse Heaven Hills. These AVAs are very successful at producing premium quality Merlot, Cabernet Sauvignon and Syrah Wines .",
        },
    },
    {
        "country": "UY",
        "name": "Montevideo",
    },
    {
        "country": "UY",
        "name": "Canelones",
    },
    {
        "country": "UY",
        "name": "Maldonado",
        "subregions": [
            {"name": "Garzón"},
            {"name": "José Ignacio"},
        ],
    },
    {
        "country": "UY",
        "name": "Colonia",
    },
    {
        "country": "UY",
        "name": "San José",
    },
    {
        "country": "AL",
        "name": "Berat",
    },
    {
        "country": "AL",
        "name": "Korça",
    },
    {
        "country": "AL",
        "name": "Leskovik",
    },
    {
        "country": "AL",
        "name": "Lezhë",
    },
    {
        "country": "AL",
        "name": "Përmet",
    },
    {
        "country": "AL",
        "name": "Shkoder",
    },
    {
        "country": "AL",
        "name": "Tirana County",
    },
    {
        "country": "AT",
        "name": "Niederösterreich",
        "synonyms": ["Lower Austria", "Northeastern and eastern", "Niederosterreich"],
        "subregions": [
            {
                "name": "Kamptal",
                "description": {
                    "default": "",
                    "sommelier": "Named after the river Kamp that runs through it, the Kamptal’s principal town is Langenlois, Austria’s largest wine-producing town. Kamptal is one of the most successful wine regions in Austria, and boasts a high proportion of outstanding, high quality wine producers. Culture and tourism also enjoy particular prominence here. Since the 2008 vintage, the designation Kamptal DAC has been used to label Grüner Veltliner and Riesling produced in classic-to-middleweight styles and as dense, dry Reserve wines.",
                    "julie": "",
                },
            },
            {
                "name": "Kremstal",
                "description": {
                    "default": "",
                    "sommelier": "The vineyards in the Kremstal are divided into three distinct areas: the historic city of Krems, whose western “Stein” district borders directly with the Wachau, the Krems valley, with its thick loess nappes to the east, and finally, the small wine villages south of the Danube clustered around the imposing Göttweig Abbey. Since 2007, the Kremstal DAC designation has been synonymous with spicy Grüner Veltliner wines and elegant, mineral-driven Rieslings, which are not only produced in a fresh, classic-to-middleweight style, but also as dense Reserve wines.",
                    "julie": "",
                },
            },
            {
                "name": "Wachau",
                "description": {
                    "default": "",
                    "sommelier": "The Wachau corresponds to the stretch of the Danube valley between Melk and Krems. This wonderfully scenic part of the Austrian landscape has been declared a World Cultural Heritage site. Extraordinarily distinctive wines are produced here, some of which grow on steeply terraced hillsides. From the 2020 vintage onwards, wines produced here are able to use the designation Wachau DAC. The best vineyards here produce some of the world’s finest white wines with decades of ageing potential, especially those produced from Grüner Veltliner and Riesling grapes.",
                    "julie": "",
                },
            },
            {
                "name": "Wagram",
                "description": {
                    "default": "",
                    "sommelier": 'In this region, the vineyards are divided between two distinctly different zones. The first zone, north of the Danube, lies directly to the east of the Kamptal, where the "Wagram" (a vast terrace of land) stretches eastwards around 30 km. The second zone, south of the Danube, home to the small wine villages of the Tulln Basin, as well as the historic wine-growing town of Klosterneuburg, is just a stone\'s throw away from Vienna.',
                    "julie": "",
                },
            },
            {
                "name": "Traisental",
                "description": {
                    "default": "",
                    "sommelier": "The Traisental is one of the youngest wine-growing regions in Austria, having only existed in its present form since 1995. It is also one of the smallest in the country, but when it comes to the region’s Grüner Veltliner, the Traisental has a commanding presence. An integral part of the small wine villages here are the traditional Buschenschank taverns, but a real step back into the past is provided by the historic towns of Traismauer and Herzogenburg. Typical fruity and spicy Grüner Veltliner and robust, mineral-driven Riesling have been marketed under the Traisental DAC designation since the 2006 vintage.",
                    "julie": "",
                },
            },
            {
                "name": "Weinviertel",
                "description": {
                    "default": "",
                    "sommelier": "The Weinviertel may be a familiar name to all Austrian wine lovers, but awareness of Lower Austria’s largest wine-growing region is also growing internationally – the region covers roughly 14,000 hectares and produces a substantial variety of wines. The main driver behind this success is Grüner Veltliner, especially in the form of Weinviertel DAC and Weinviertel DAC Reserve or Große Reserve, which express the full extent of their regional typicity.",
                    "julie": "",
                },
            },
            {
                "name": "Thermenregion",
                "description": {
                    "default": "",
                    "sommelier": "The vines of the wine-growing region Thermenregion line the hillsides of the Wienerwald (Vienna Woods), stretching from the outskirts of Vienna along a ridge containing the Anninger mountain, the highest elevation south of Baden. Even today, white wine is prominent in the north of the region around Gumpoldskirchen, with a special focus on the autochthonous varieties Zierfandler (also known as Spätrot) and Rotgipfler. In the south of the region, red wine predominates with the varieties Sankt Laurent and Pinot Noir. As from 2023, “Thermenregion DAC” can be applied to the region’s red and white wines displaying regional typicity.",
                    "julie": "Baden is a large region in southern Germany. Baden covers a large area along the French border and touches the Swiss border to the south. Germany's warmest winegrowing region, Kaiserstuhl, is located in Baden. Spätburgunder and other red grapes are preferred, as the entire area is too hot for quality Riesling. Weissherbst, a local rosé wine, is a popular traditional style of the region. ",
                },
            },
            {
                "name": "Carnuntum",
                "description": {
                    "default": "",
                    "sommelier": "For many years now, archaeologists have been digging up evidence of ancient Roman culture from Carnuntum’s soils. While the ground is indeed rich in history, the region’s vines provide modern-day treasures, particularly in the form of regionally typical red wines produced from Zweigelt and Blaufränkisch. Likewise, Chardonnay, Pinot Blanc and Grüner Veltliner also deliver white DAC wines of impressive character.",
                    "julie": "",
                },
            },
        ],
        "description": {
            "default": "",
            "sommelier": "Niederösterreich (Lower Austria) is Austria’s largest Qualitätswein wine-growing region. This region is associated with a wealth of different origins and wine styles produced from unique domestic grapes, as well as international varieties. Niederösterreich is home to eight specific Qualitätswein wine-growing regions, ranging from Wachau in the west to Carnuntum in the east. It can be divided into three rough climate zones: the Weinviertel in the north, the Danube region and its tributary valleys to the west of Vienna, and Niederösterreich, with its Pannonian climate, in the south-east.",
            "julie": "Lower Austria, or Niederösterreich, is the largest winegrowing region in the country. Most of the vineyards are located along the path of the Danube River and its tributaries. The most planted grape varieties in the region is Grüner Veltliner. There are a total of eight subzones: Weinviertel DAC, Carnuntum DAC, Traisental DAC, Wagram DAC, Kremstal DAC, Kamptal DAC, Wachau DAC, and Thermenregion DAC.",
        },
    },
    {
        "country": "AT",
        "name": "Burgenland",
        "description": {
            "default": "",
            "sommelier": "Burgenland, the easternmost of Austria’s federal states, is influenced by the hot, continental Pannonian climate and produces the most opulent and authoritative red wines in Austria, along with complex whites and extraordinarily fine sweet wines. In terms of natural conditions, the regional particularities of Burgenland should not be underestimated.",
            "julie": "",
        },
        "subregions": [
            {
                "name": "Eisenberg",
                "description": {
                    "default": "",
                    "sommelier": "The southernmost part of Burgenland is home to the state’s purest and most natural viticultural landscape, stretching between Rechnitz in the north and Güssing in the south. The regionally authentic red wines, especially those made from Blaufränkisch with the protected designation of origin Eisenberg DAC , are characterised by a particular mineral spiciness. Elegant, spicy white wines, particularly Welschriesling, set the tone, as does the ancient speciality here, Uhudler.",
                    "julie": "",
                },
            },
            {
                "name": "Leithaberg",
                "description": {
                    "default": "",
                    "sommelier": "The Leitha Range is home to the good all-rounders. Hardly any other wine-growing region has such a variety of wine types as those grown on the western banks of Lake Neusiedl. Leithaberg DAC wines can be red or white, and always display the minerality, dynamic tension and vibrancy that is typical of the region.",
                    "julie": "",
                },
            },
            {
                "name": "Mittelburgenland",
                "description": {
                    "default": "",
                    "sommelier": "In the vineyards of the Mittelburgenland wine-growing region, Blaufränkisch takes centre stage and articulates its origins perfectly in the region’s DAC wines. Four municipalities set the tone: Deutschkreutz, Horitschon, Lutzmannsburg and Neckenmarkt. Mittelburgenland is also known as “Blaufränkischland”, due to it being Austira’s key wine-growing region for this grape variety.",
                    "julie": "",
                },
            },
            {
                "name": "Neusiedlersee",
                "description": {
                    "default": "",
                    "sommelier": "Austria’s Neusiedlersee wine-growing region, situated to the east of Lake Neusiedl, stretches from the hills and the wine capital of Gols, over the flat Heideboden, and down to the melancholic Seewinkel area. The vineyards on the banks of Lake Neusiedl – a shallow steppe lake – are home to a wealth of different grape varieties. The Neusiedlersee DAC has been recognised since the 2012 vintage and is synonymous with fruity, harmonious red Zweigelt wines that reflect the region’s climate and soil. This designation of origin also includes a Reserve category.",
                    "julie": "",
                },
            },
            {
                "name": "Rosalia",
                "description": {
                    "default": "",
                    "sommelier": "The Rosalia wine-growing region is situated on the eastern slope of the Rosalia Mountains, which extend along the border between Lower Austria and Burgenland. The Pannonian climate and loam soils offer perfect conditions for growing Blaufränkisch and Zweigelt, the region’s two most prominent grape varieties.",
                    "julie": "Burgenland produces some of Austria’s best red and sweet white wines. Burgenland borders Hungary, and shares many viticultural and climactic traits with regions just across the border. The hot continental, Pannonian climate in Burgenland is tempered by the cooling influence of the Neusiedlersee lake. Blaufränkisch is the most planted red grape. Zweigelt has significant acreage and St. Laurent is being cultivated with increasing frequency. Burgunland includes the following DACs : Mittleburgenland, Leithaberg, Eisenberg, Neusiedlersee, Rosalia and Ruster Ausbrusch – a DAC dedicated to the production of sweet wines made from botrytised berries. ",
                },
            },
        ],
    },
    {
        "country": "AT",
        "name": "Steiermark",
        "synonyms": ["Styria"],
        "subregions": [
            {
                "name": "Südsteiermark",
                "description": {
                    "default": "",
                    "sommelier": "Südsteiermark is reputed for fresh, fragrant wines, especially those produced using the region’s flagship variety, Sauvignon Blanc. However, Südsteiermark accommodates a wide assortment of other grape varieties, including Welschriesling, Morillon ­(Chardonnay), Muskateller and Traminer. Despite this being one of Europe’s most picturesque viticultural regions, the extremely steep gradient of most vineyards make winegrowing here a significant challenge.",
                    "julie": "",
                },
            },
            {
                "name": "Vulkanland Steiermark",
                "description": {
                    "default": "",
                    "sommelier": "The Vulkanland Steiermark wine-growing region is characterised by many small viticultural enclaves. Here, vineyards stretch up the sides of extinct volcanoes, giving the landscape a truly unique character. The vineyards cultivated in this region are concentrated around Klöch, St. Anna am Aigen and Straden. One grape variety here holds particular appeal: the highly aromatic Traminer. Traditional Buschenschank taverns are the sales channel of choice for this region’s wines.",
                    "julie": "",
                },
            },
            {
                "name": "Weststeiermark",
                "description": {
                    "default": "",
                    "sommelier": "Weststeiermark may only have approximately 660 hectares of land under vine, but the wine-growing families here cultivate them diligently to create an astonishing variety of products: polished white wines from numerous grape varieties, as well as the zesty, acidic Schilcher which is the undisputed star of the region. Internationally recognised as a regional speciality, this unique rosé terroir wine is vinified from Blauer Wildbacher grapes, which are the predominant local variety.",
                    "julie": "",
                },
            },
        ],
        "description": {
            "default": "",
            "sommelier": "The world abounds with wine-growing regions that produce weightier wines than Steiermark – and certainly wines with a higher alcohol content. There are no other wines in the world, however, that express their typicity of origin in such a fresh, brilliant and elegant way as those from southern Styria.",
            "julie": "",
        },
    },
    {
        "country": "AT",
        "name": "Wien",
        "synonyms": ["Vienna"],
        "description": {
            "default": "",
            "sommelier": "Viticulture in a city? Often, urban vineyards serve no other purpose than attracting tourists – but not in Vienna! The city’s vineyards play a key role in the local economy and help preserve the green belt that surrounds the city – not to mention the fact that they produce some high-quality wines! The special type of wine produced in Wien – the Wiener Gemischter Satz (field blend) – was added to the list of Austrian DAC wines in 2013 and has now become the quintessential symbol of Wien’s wines.",
            "julie": "",
        },
    },
    {
        "country": "AT",
        "name": "Bergland",
        "description": {
            "default": "",
            "sommelier": 'Wine production in Austria is not only found in the wine-growing areas of "Weinland" (to include Niederösterreich, Burgenland and Wien) and "Steirerland" (Steiermark), but also in every other federal state. These are included in the wine-growing area of "Bergland".',
            "julie": "",
        },
    },
    {
        "country": "BE",
        "name": "Côtes de Sambre et Meuse",
        "synonyms": ["Sambre et Meuse", "Côtes de Sambre et Meuse"],
        "description": {
            "default": "",
            "sommelier": "This region lies on the banks of the Sambre and the Meuse Rivers and on the valleys that have formed in the landscape. The soil consists of a shallow clay or loam layer with an alternating subsoil of limestone, sand and slate.",
            "julie": "",
        },
    },
    {
        "country": "BE",
        "name": "Hagelandse wijn",
        "synonyms": ["Hageland"],
        "description": {
            "default": "",
            "sommelier": "Hageland is the oldest Denomination of Origin in Belgium, founded in 1997. It's located in between the cities of Leuven, Aarschot, Diest and Landen. The best vineyards lie on the Southern slopes. The soil of Hageland are iron-rich which gives a nice minerality to the wines. As in other wine regions in Belgium a whole range of grapes is planted.",
            "julie": "",
        },
    },
    {
        "country": "BE",
        "name": "Haspengouw",
        "synonyms": ["Hesbaye", "Haspengauw"],
        "description": {
            "default": "",
            "sommelier": "Haspengauw lies in the North-East of the Belgian province Limburg. This is the oldest Belgian wine region with winemaking practices dating back to the 10th Centrury AD. The region has a loam and marl soil with chalkrich subsoil. The vineyards in the appellation are spread out across various soil-types which leads to stylistic differences between the various domaines. The region produces (arguably) the most elegant and refined wines of the country.",
            "julie": "",
        },
    },
    {
        "country": "BE",
        "name": "Heuvelland",
        "description": {
            "default": "",
            "sommelier": "In Heuvelland a variety of grape varieties are grown to produce wines. The winestyles are mostly light and fresh and the majority of wine produced is Sparkling. Yearly 220.000 wines are bottles.",
            "julie": "",
        },
    },
    {
        "country": "BA",
        "name": "Čapljina",
    },
    {
        "country": "BA",
        "name": "Čitluk",
    },
    {
        "country": "BA",
        "name": "Ljubuški",
    },
    {
        "country": "BA",
        "name": "Međugorje",
    },
    {
        "country": "BA",
        "name": "Mostar",
    },
    {
        "country": "BA",
        "name": "Stolac",
    },
    {
        "country": "BA",
        "name": "Trebinje",
    },
    {
        "country": "BG",
        "name": "Black Sea",
    },
    {
        "country": "BG",
        "name": "Danubian Plain",
    },
    {
        "country": "BG",
        "name": "Rose Valley",
    },
    {
        "country": "BG",
        "name": "Thrace",
    },
    {
        "country": "BG",
        "name": "Valley of the Struma River",
        "synonyms": ["Struma River Valley"],
    },
    {
        "country": "HR",
        "name": "Continental Croatia",
        "subregions": [
            {"name": "Moslavina"},
            {"name": "Plešivica"},
            {"name": "Podunavlje"},
            {"name": "Pokuplje"},
            {"name": "Prigorje"},
            {"name": "Slavonia"},
            {"name": "Zagorje"},
        ],
    },
    {
        "country": "HR",
        "name": "Littoral Croatia",
        "subregions": [
            {"name": "Croatian Coast"},
            {"name": "Dalmatian Interior"},
            {"name": "Central and South"},
            {"name": "Northern"},
            {"name": "Istria"},
        ],
    },
    {
        "country": "CY",
        "name": "Commandaria",
    },
    {
        "country": "CY",
        "name": "Laona",
    },
    {
        "country": "CY",
        "name": "Vouni Panagias – Ambelitis",
    },
    {
        "country": "CY",
        "name": "Krasochoria Lemesou",
    },
    {
        "country": "CY",
        "name": "Pitsilia",
    },
    {
        "country": "CY",
        "name": "Diarizos Valley",
    },
    {
        "country": "CZ",
        "name": "Moravia",
        "subregions": [
            {"name": "Mikulov"},
            {"name": "Slovácko"},
            {"name": "Velké Pavlovice"},
            {"name": "Znojmo"},
        ],
    },
    {
        "country": "CZ",
        "name": "Bohemia",
        "subregions": [
            {"name": "Litoměřice"},
            {"name": "Mělník"},
        ],
    },
    {
        "country": "CZ",
        "name": "Prague",
        "subregions": [
            {"name": "Gazebo at Gröbe's Villa"},
            {"name": "St. Clare's"},
            {"name": "St. Wenceslas' Vineyard at Prague castle"},
            {"name": "Salabka, Troja"},
        ],
    },
    {
        "country": "FR",
        "name": "Alsace",
        "synonyms": ["Elsass", "Elsaß", "Elzas", "Haut-Rhin", "Bas-Rhin"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Alsace is divided into two zones, Haut-Rhin and Bas-Rhin. The region is separated from the rest of France by the Vosges Mountains in the west. The mountains provide a rain shadow effect, and as a result, Alsace is one of France’s driest and sunniest climates. Colmar, capital of the Haut-Rhin département, is the driest city in France. The vineyards of Alsace is a long, narrow vineyard that runs along the lower slopes and foothills of the Vosges, and the exact aspect and location of each vineyard is of importance in this semi-continental climate. Alsatian vineyards have myriad soil types : granite, limestone, schist, clay, gravel, chalk, loess, and a local pink sandstone called grés de Vosges. 90% of the wine production in Alsace is white and the region is planted with Riesling, Pinot Gris, Muscat, Gewürztraminer, Pinot Blanc, Chasselas, Sylvaner and Savagnin Rose. The only red grape permitted in the region for AOP wines is Pinot Noir. Since 1975, fifty-one vineyards of exception have been elevated to a Grand Cru AOP status. Alsace is famous for the quality of its sweet wines which can be labelled as “VT” Vendanges Tardives, meaning late harvests, and as “SGN” Sélection de Grains Nobles, translating as selection of noble berries. ",
        },
    },
    {
        "country": "FR",
        "name": "Charentais",
        "synonyms": ["Charente", "Charentes", "Charente-Maritime"],
        "subregions": [
            {"name": "Cognac"},
            {"name": "Pineau des Charentes"},
        ]
    },
    {
        "country": "FR",
        "name": "Bordeaux",
        "synonyms": ["Bordelais", "Bordo"],
        "subregions": [
            {"name": "Barsac"},
            {"name": "Entre-Deux-Mers"},
            {"name": "Fronsac"},
            {"name": "Graves"},
            {"name": "Haut-Médoc"},
            {"name": "Margaux"},
            {"name": "Médoc"},
            {"name": "Pauillac"},
            {"name": "Pessac-Léognan"},
            {"name": "Pomerol"},
            {
                "name": "Saint-Émilion",
                "subregions": [
                    {"name": "Lussac-Saint-Emilion", "synonyms": ["Lussac"]},
                    {"name": "Montagne-Saint-Emilion", "synonyms": ["Montagne"]},
                    {"name": "Puisseguin-Saint-Emilion", "synonyms": ["Puisseguin"]},
                    {"name": "Saint-Emilion Grand Cru"},
                    {"name": "Saint-Georges-Saint-Emilion", "synonyms": ["Saint-Georges"]},
                ]
            },
            {"name": "Saint-Estèphe"},
            {"name": "Saint-Julien"},
            {"name": "Sauternes"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The region of Bordeaux is France's second largest region of production by volume behind the Languedoc region and as approximatively 115,000 hectares of vines planted. The region is located near the Atlantic ocean and is crossed by the Dordogne and the Garonne River that meets to form the Estuary of Gironde. The most planted grape varieties of Bordeaux are : Cabernet Sauvignon, Merlot, Cabernet Franc, Petit Verdot, Malbec, and Carmènere. Cabernet Sauvignon is known to thrive on the left bank of the Garonne River in the well drained soils of the Médoc and Graves areas. Merlot and Cabernet Franc have been historically more suited on the right bank of the Dordogne River where they produce the prestigious appellations of Saint Emilion and Pomerol.  Sauvignon blanc and Sémillon are commonly blended to produce the dry wines of the regions that range in style from light, inexpensive and fruity to complex and age-worthy on regions such as Pessac-Léognan. Sémillon is also the main player for the production of the iconic botrytised sweet wines of Sauternes and Barsac. ",
        },
    },
    {
        "country": "FR",
        "name": "South West France",
        "synonyms": ["Sud-Ouest"],
        "subregions": [
            {
                "name": "Garonne",
                "synonyms": ["Tarn-et-Garonne"],
                "subregions": [{"name": "Cahors"}],
            },
            {
                "name": "Bergerac & Dordogne",
                "synonyms": ["Bergeracois", "Bergerac", "Dordogne"],
                "subregions": [
                    {"name": "Monbazillac"},
                    {"name": "Pécharmant"},
                    {"name": "Rosette"},
                ],
            },
            {
                "name": "Gascogne",
                "synonyms": ["Gascony"],
                "subregions": [
                    {"name": "Armagnac"},
                    {"name": "Côtes de Gascogne"},
                    {"name": "Tursan"},
                    {"name": "Béarn"},
                    {"name": "Jurançon"},
                    {"name": "Madiran"},
                ],
            },
        ],
    },
    {
        "country": "FR",
        "name": "Burgundy",
        "synonyms": ["Bourgogne"],
        "subregions": [
            {"name": "Chablis"},
            {
                "name": "Côte Chalonnaise",
                "subregions": [
                    {"name": "Givry"},
                    {"name": "Mercurey"},
                    {"name": "Montagny"},
                    {"name": "Bouzeron"},
                    {"name": "Rully"},
                ],
            },
            {
                "name": "Côte d'Or",
                "subregions": [
                    {
                        "name": "Côte de Beaune",
                        "subregions": [
                            {"name": "Aloxe-Corton"},
                            {"name": "Auxey-Duresses"},
                            {"name": "Beaune"},
                            {"name": "Chassagne-Montrachet"},
                            {"name": "Meursault"},
                            {"name": "Santenay"},
                            {"name": "Puligny-Montrachet"},
                            {"name": "Volnay"},
                            {"name": "Pommard"},
                            {"name": "Saint-Aubin"},
                        ],
                    },
                    {
                        "name": "Côte de Nuits",
                        "subregions": [
                            {"name": "Chambolle-Musigny"},
                            {"name": "Gevrey-Chambertin"},
                            {"name": "Nuits-Saint-Georges"},
                            {"name": "Vosne-Romanée"},
                            {"name": "Morey-Saint-Denis"},
                            {"name": "Fixin"},
                            {"name": "Marsannay"},
                        ],
                    },
                ],
            },
            {
                "name": "Mâconnais",
                "subregions": [{"name": "Pouilly-Fuissé"}],
            },
            {
                "name": "Beaujolais",
                "subregions": [
                    {
                        "name": "Beaujolais Villages",
                        "synonyms": ["Beaujolais-Villages"],
                    },
                    {
                        "name": "Beaujolais Crus",
                        "synonyms": ["Cru Beaujolais"],
                        "subregions": [
                            {"name": "Brouilly"},
                            {"name": "Chénas"},
                            {"name": "Chiroubles"},
                            {"name": "Côte de Brouilly"},
                            {"name": "Fleurie"},
                            {"name": "Juliénas"},
                            {"name": "Morgon"},
                            {"name": "Moulin-à-Vent"},
                            {"name": "Régnié"},
                            {"name": "Saint-Amour"},
                        ],
                    },
                ]
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Burgundy streches over 230km between Macon and Auxerre and covers just over 30,000ha of vines. The two iconic grape varities of the region are Pinot Noir for the red wines and Chardonnay for the whites. However, in recent years, Aligoté has also started to build a reputation for itself. Burgundy is divided into four main areas, from North to South : Chablis, Côte de Nuits, Côte de Beaune and Maconnais. ",
        },
    },
    {
        "country": "FR",
        "name": "Champagne",
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The region of Champagne is located in Northern France, 150km East of Paris and is internationally acclaimed for its production of high quality sparkling wines made by traditionnal method, locally known as Champagne method. The region is divided into 5 main areas called : Montagne de Reims, Côte des Blancs, Valais de la Marne, Sézannais and Aube region. The most planted grape varities are Pinot Noir, Pinot Meunier and Chardonnay. Today, the region also produces some still wines white and red sold under the Côteaux Champenois AOP as well as some still rosé wines produces in Les Riceys area and sols as Rosé des Riceys AOP. ",
        },
        "subregions": [
            {"name": "Montagne de Reims"},
            {"name": "Côte des Blancs"},
            {"name": "Vallée de la Marne"},
            {"name": "Côte des Bar"},
            {
                "name": "Côte de Sézanne",
                "synonyms": ["Sézannais"],
            },
            {"name": "Côte des Riceys"},
            {"name": "Aube"},
        ],
    },
    {
        "country": "FR",
        "name": "Corsica",
        "subregions": [
            {"name": "Ajaccio"},
            {"name": "Cap Course"},
            {"name": "Patrimonio"},
            {
                "name": "Vin de Corse",
                "subregions": [
                    {"name": "Calvi"},
                    {"name": "Figari"},
                    {"name": "Porto-Vecchio"},
                    {"name": "Sartène"},
                ],
            },
        ],
    },
    {
        "country": "FR",
        "name": "Jura",
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The Jura is located just South of Alsace and to the East of Burgundy. The region’s vineyards are found on the mountains’ lower slopes and the climate is continental, turning harshly cold in the wintertime. Vin Jaune, a local speciality made from the Savagnin blanc grape (called locally Naturé), is aged under a layer of yeasts called “fleur” for over 6 years before being bottled. It is sold in a traditional 62cl bottle called Clavelin and is reminiscent of Fino sherries in terms of flavours. The region also produces some high quality white, red and sweet wines (Vin de Paille) from Chardonnay, Naturé, Pinot Noir, Trousseau and Poulsard.",
        },
    },
    {
        "country": "FR",
        "name": "Languedoc-Roussillon",
        "synonyms": ["Languedoc", "Roussillon", "Languedoc Roussillon"],
        "subregions": [
            {
                "name": "Pinet",
                "synonyms": ["Picpoul de Pinet"],
            },
            {
                "name": "Terrasses du Larzac",
                "synonyms": ["Larzac"],
            },
            {
                "name": "Banyuls",
                "synonyms": ["Banyuls Grand Cru", "Banyuls Rimage"],
            },
            {"name": "Cabardès"},
            {"name": "Collioure"},
            {"name": "Corbières"},
            {"name": "Côtes du Roussillon"},
            {"name": "Fitou"},
            {
                "name": "Limoux",
                "synonyms": ["Blanquette de Limoux", "Crémant de Limoux"],
            },
            {"name": "Maury"},
            {"name": "Minervois"},
            {"name": "Rivesaltes"},
            {"name": "Saint-Chinian"},
            {
                "name": "Cévennes",
                "synonyms": ["Vin De Pays des Cévennes"],
            },
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Located on the southern coast of France, the Languedoc-Roussillon wine region, nowadays called Occitanie region, runs in a crescent shape between Provence to the East and the Spanish border to the South.  The region has the biggest acreage under vines in France and in some vintages produces close to 30% of the national production. However, most of the wines produced are sold at IGP level. The region is mostly known for its red wine production even though white and red wines are also produced. Some of the most famous Appellations d’Origine Protégée (AOP) include Fitou, Corbières, Corbières-Boutenac, Minervois, Minervois-la-Livinière, Saint Chinian and Faugères. Wines are produces from blends that generally include Grenache Noir, Syrah, Carignan. Crémant de Limoux is dedicated to the production of sparkling wines made from Chardonnay, Chenin Blanc, Mauzac and Pinot. The eastern half of Languedoc is dominated by the regional appellation Languedoc AOP. Formerly Coteaux du Languedoc AOC, this appellation encompasses nearly all of Languedoc-Roussillon, extending from the Spanish border to the city of Nîmes. Languedoc AOP covers the production of red, rosé, and white wines and encompasses 11 geographic designations. The Languedoc has also build its reputation on the production of sweet fortified wines known as “vins doux naturels”. The white examples are made from the Muscat blanc à petits grains. Muscat d’Alexandrie, Grenache (Gris and Blanc), Maccabéo, Tourbat. The red examples can be sold young, when young and fruity, or can be aged in an oxidative environment to where they develop some rancio style flavours. The main red grape used for the purpose of red vin doux naturel wine is Grenache Noir. ",
        },
    },
    {
        "country": "FR",
        "name": "Loire Valley",
        "synonyms": ["Loire", "Val de Loire"],
        "subregions": [
            {
                "name": "Anjou",
                "synonyms": ["Anjou-Saumur", "Saumur"],
                "subregions": [
                    {"name": "Saumur-Champigny"},
                    {
                        "name": "Quarts de Chaume",
                        "synonyms": ["Quarts de Chaume Grand Cru"],
                    },
                    {"name": "Coteaux du Layon"},
                    {"name": "Bonnezeaux"},
                    {
                        "name": "Savennières",
                        "synonyms": ["Savennières Roche aux Moines", "Savennières Coulée de Serrant"],
                    },
                ],
            },
            {
                "name": "Central Loire",
                "synonyms": ["Centre-Loire"],
                "subregions": [
                    {"name": "Chinon"},
                    {"name": "Menetou-Salon"},
                    {"name": "Quincy"},
                    {"name": "Reuilly"},
                    {"name": "Pouilly-Fumé"},
                    {"name": "Sancerre"},
                ],
            },
            {
                "name": "Touraine",
                "subregions": [
                    {"name": "Bourgueil"},
                    {
                        "name": "Montlouis",
                        "synonyms": ["Montlouis-sur-Loire"],
                    },
                    {"name": "Vouvray"},
                    {
                        "name": "Touraine Oisly",
                        "synonyms": ["Oisly", "Touraine-Oisly"],
                    },
                    {
                        "name": "Touraine Mesland",
                        "synonyms": ["Mesland", "Touraine-Mesland"],
                    },
                    {
                        "name": "Touraine Amboise",
                        "synonyms": ["Amboise", "Touraine-Amboise"],
                    },
                    {
                        "name": "Touraine Azay-le-Rideau",
                        "synonyms": ["Azay-le-Rideau", "Touraine-Azay-le-Rideau"],
                    },
                    {
                        "name": "Touraine Chenonceaux",
                        "synonyms": ["Chenonceaux", "Touraine-Chenonceaux"],
                    }
                ],
            },
            {
                "name": "Pays Nantais",
                "synonyms": ["Muscadet", "Nantais", "Pays Nantes"],
                "subregions": [
                    {"name": "Muscadet Sèvre et Maine"},
                    {"name": "Muscadet Coteaux de la Loire"},
                    {"name": "Muscadet Côtes de Grandlieu"},
                ],
            },

        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The Loire is France’s longest river and run for 1006 kilometres from the Massif Central to the Atlantic Ocean. Along, the Loire, some of France most qualitative vineyards can be found. The region produces more white wine than any other French region is second to Champagne when it comes to sparkling wine production. The most classical white grapes of the Loire Valley are Chenin Blanc, Sauvignon Blanc and Melon de Bourgogne while Cabernet Franc (known locally as Breton), Pinot Noir and Gamay are the most planted red grapes. The Loire Valley wine region is divided into 4 sub-regions : Pays Nantais, Touraine, Anjou and Central Loire. Famous AOPs include Muscadet, Savennières, Chinon, Vouvray, Sancerre and Pouilly-Fumé. ",
        },
    },
    {
        "country": "FR",
        "name": "Lorraine",
    },
    {
        "country": "FR",
        "name": "Madiran",
    },
    {
        "country": "FR",
        "name": "Provence",
        "synonyms": ["Côtes de Provence", "Cotes de Provence"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Provence, the birthplace of French wine, lies to the east of the Rhône basin on the sun-drenched Mediterranean coast. The region is world famous for its pale-hued, dry rosés which represent over 80% of the region’s total wine production.Three-quarters of the wines are sold under the Côtes de Provence AOP which is solely made as rosé. Cinsault, Grenache, Mourvèdre, Syrah, and the local Tibouren are the main red grape varieties planted.  Other appellations of the region, offering high quality wines in all colour, include Bandol, Casis, Les-Baux-de-Provence, Palette and Bellet AOPs. ",
        },
    },
    {
        "country": "FR",
        "name": "Coteaux du Pont du Gard",
        "synonyms": ["Pont du Gard"],
    },
    {
        "country": "FR",
        "name": "Rhône",
        "synonyms": [
            # "Côtes du Rhône",
            # "Cotes du Rhone",
            "Rhône Valley",
            "Rhone Valley",
        ],
        "subregions": [
            {"name": "Beaumes-de-Venise"},
            {"name": "Château-Grillet"},
            {
                "name": "Châteauneuf-du-Pape",
                "synonyms": ["Chateauneuf-du-Pape", "Chateauneuf du Pape"],
            },
            {"name": "Lirac"},
            {"name": "Luberon"},
            {"name": "Condrieu"},
            {"name": "Cornas"},
            {"name": "Côte du Rhône-Villages"},
            {"name": "Côte-Rôtie"},
            {
                "name": "Côtes du Rhône",
                "synonyms": ["Cotes du Rhone"],
            },
            {"name": "Crozes-Hermitage"},
            {"name": "Hermitage"},
            {"name": "Gigondas"},
            {"name": "St. Joseph"},
            {"name": "Saint-Péray"},
            {"name": "Vacqueyras"},
            {
                "name": "Tavel",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "The Rhône Valley runs from its headwaters in Switzerland the French Mediterranean Sea. The Rhône Valley as a wine region refers to two clusters of appellations along the banks of the River in France, between the city of Vienne (France) and Avignon and is mostly dedicated to the production of red wines. The region is divided between the Northern Rhône and the Southern Rhône. The Northern Rhône is home to the Syrah grape variety and to the legendary vineyards of Côte Rôtie and Hermitage as well as to the tiny appellations of Condrieu and Château Grillet which produce world class Viognier based white wines. The Southern Rhône vineyards are mostly located between Montélimar and Avignon. This part of the Rhône Valley has built its reputation around the grape Grenache Noir, usually blended with Mourvèdre, Cinsault and other varieties. Chateauneuf-du-Pape, the most famous AOC of the region, permits the use of 13 different grape varieties. Other noteworthy appellations include Gigondas, Vacqueyras, Ventoux, Tavel, etc. ",
            "julie": "",
        },
    },
    {
        "country": "FR",
        "name": "Savoy",
        "synonyms": ["Savoie"],
        "subregions": [
            {"name": "Bugey"},
            {
                "name": "Vin de Savoie",
            }
        ],
    },
    {
        "country": "GE",
        "name": "Abkhazia",
    },
    {
        "country": "GE",
        "name": "Kartli",
    },
    {
        "country": "GE",
        "name": "Imereti",
    },
    {
        "country": "GE",
        "name": "Racha-Lechkhumi and Kvemo Svaneti",
    },
    {
        "country": "DE",
        "name": "Ahr",
        "synonyms": ["Ahr Valley"],
        "description": {
            "default": "",
            "sommelier": "The Ahr only has 560 hectares of vineyards, making it one of the smallest in Germany. It produces mainly red wines (80%) from Spätburgunder (Pinot Noir) and Frühburgunder. The Ahr is the northernmost wine region in the western part of the country. The climate is mild and favorable and can be very hot and humid in the steep sites. The precipitation is relatively low. ",
            "julie": "",
        },
    },
    {
        "country": "DE",
        "name": "Baden",
        "synonyms": ["Baden-Württemberg"],
        "description": {
            "default": "",
            "sommelier": "Baden is primarily a long, slim strip of vineyards nestled between the hills of the Black Forest and the Rhine River, stretching from Heidelberg and the Tauber Valley in the north to the Swiss border and Lake Constance in the south. It has 15.200 hectares under vine (third largest in Germany). The sunny, warm climate is influenced by the region’s position between the ridges of the Palatinate Forest and the Oden Forest, and between the Vosges Mountains and the Black Forest. The region has long sun hours and warm summers, with mild winters. The relative Mediterranean climate allows for the growth of citrus fruits, almond trees, and orchids. Baden is the most important German region for Spatburgunder (Pinot Noir). More than half of the vineyards are planted with Burgunder varieties: Spätburgunder, the forementioned Pinot Noir; Grauburgunder (Pinot Gris), a dry, food-compatible wine, and Weißburgunder (Pinot Blanc), neutral enough to accompany many foods.",
            "julie": "",
        },
    },
    {
        "country": "DE",
        "name": "Franken",
        "synonyms": ["Franken", "Franconia"],
        "description": {
            "default": "",
            "sommelier": "Franken has 6.100 hectares under vine, with 80% white wines. Wurzburg is the capital and the heart of the wine region, north-west of Nnurnberg. The climate is Continental with Dry, warm summers and Dry, cold winters. Part of Franken wines’ singular personality is due to the climate: cold winters, high annual rainfall, early frosts. Long, warm autumns are rare. As a result, the late-ripening Riesling plays a minor role, and the focus is on Silvaner and Muller-Thurgau. The soils are majority of weathered rock, Colored sandstone and Shell-limestone. The finest Franken wines are traditionally bottled in a Bocksbeutel, a square green or brown flacon with a round body and short neck, which lends considerable recognition value to the region’s wines.",
            "julie": "",
        },
    },
    {
        "country": "DE",
        "name": "Hessische Bergstrasse",
    },
    {
        "country": "DE",
        "name": "Mittelrhein",
    },
    {
        "country": "DE",
        "name": "Mosel",
        "synonyms": ["Moselle", "Mosel-Saar-Ruwer", "Mosel Saar Ruwer", "The Mosel"],
        "description": {
            "default": "",
            "sommelier": "The wine-growing region along the Moselle, Saar and Ruwer rivers is considered Germany's oldest wine region, since the Romans. It has 8.700 hectares. The Mosel is named for the serpentine river, along which the banks rise so sharply that the vineyards are among the steepest in the world, up to 70% degrees! The wines on those slopes  produce effervescent wines with a fragrance reminiscent of spring blossoms, a pale color, light body and a refreshing, fruity acidity. The climate is one of the warmer climates in Germany thanks to its sheltered valley location. Steep slate slopes retain heat, and the river helps moderate climate. Ther is Sufficient rainfall, moderate climante and long growing season. The Mosel see themselves as Riesling specialists (60% of the total plantings). The late-maturing, noble white variety thrives in the conditions here. The steep slate slopes above the rivers store the sun's heat during the day and release it again at night. The roots of the vines penetrate deep into the ground to seek water and minerals. In this way, the winemakers can produce uniquely fine, fruity wines that have an enormous depth of flavor and a relatively low alcohol content - ideal for easy enjoyment. Also world-renowned are the noble-sweet wines of this region,  as well as the many excellent, dry and semi-dry wines. Rivaner (Müller-Thurgau) is the second most important grape variety and Elbling, an old grape variety on the Upper Mosel.",
            "julie": "The Mosel is one of the most scenic wine regions of the world with incredibly steep slate slopes where only vines can grow.These vineyards are impossible to harvest mechanically, and cable systems are often employed to enable workers to traverse the cliff-side vines. The Mosel is highly regarded for its production of pure, light, racy, mineral and low alcohol Rieslings that exhibits aromas of green apple, citrus and blossom. The wines produced range from dry to sweet and labelled often based on their prädikat level.  The Mosel is divided into six bereiche: Bernkastel, Burg Cochem, Saar, Ruwertal, Obermosel, and Moseltor. The Ruwer and the Saar are two tributaries of the Mosel. ",
        },
    },
    {
        "country": "DE",
        "name": "Nahe",
        "description": {
            "default": "",
            "sommelier": "Nahe has 4.200 hectares under vine, making it one of the smallest wine growing regions in Germany. The Nahe region is named after the river that traverses the valleys of the forested Hunsrück Hills to Bingen, west of Rheinhessen. The high Hunsrück mountains provide protection from the cold winds, mild temperatures and lots of sunshine and no frost. The entire rock cycle of volcanic, sedimentary (sandstone, clay, limestone) and slate rocks is present in the Nahe. The steeper sites of volcanic or weathered stone, and those with red, clayish slate seem predestined for elegant, piquant Riesling wines of great finesse and a light spiciness, while flatter sites of loam, loess and sandy soils yield lighter, fragrant Müller-Thurgau wines with a flowery note. Silvaner grape thrives in a number of soils and produces full-bodied, earthy wines. Nahe also produces Grauburgunder (Pinot Gris), Weissburgunder (Pinot Blanc) Dornfelder & Spatburgunder (Pinot Noir).",
            "julie": "The Nahe region is one of the smallest of Germany and it is located to the west of the Rheinhessen, along the Nahe River, a tributary of the Rhine. The region has an extraordinary range of soil types and is protected from cold winds by the Hunsrück mountain range. The Nahe receives plenty of sunshine each year. The Region produces over 75% of white wine with Riesling counting for approximately 30% of the plantings. The steeper sites of volcanic weathered stones and those with red clay and slates are the preferred ones for Riesling. Other white grape varities such as Rivaner, Silvaner, Pinot Gris and Pinot Blanc and also increasingly cultivated. Dornfelder and Spätburgunder are the most planted red grapes. ",
        },
    },
    {
        "country": "DE",
        "name": "Palatinate",
        "synonyms": ["Pfalz", "Pflaz"],
        "description": {
            "default": "",
            "sommelier": "The Pfalz is Germany’s second largest regions (and Germany’s largest red wine region), producing every third bottle of German wine purchased domestically, with 23.500 hectares under vine. The climate is variable with lots of sun, making it one of Germany’s warmest regions. The mild climate is due to the slopes of the Palatinate Forest. The Pfalz runs from the south of Worms to the French border (Alsace), between the foothills of the Palatinate Forest. Loam is prevalent, often in a mixture with other soil types, such as loess, chalk, clay, colored sandstone or sand. The English equivalent, Palatinate, is sometimes used to refer to the Pfalz. Pleasant, mild white wines rich in bouquet and full of body are produced from Riesling, Müller-Thurgau and Grauburgunder (Pinot Gris) grapes in the Pfalz, while deep-coloured and quite complex red wines are made from Dornfelder grapes, Spatburgunder (Pinot Noir) and Portugueser grape.",
            "julie": "The Pfalz, also known as the Palatinate is one of the warmest winegrowing regions of Germany and is located at the border with Alsace in France. The region has a very complex soil makeup with red sandstone, limestones, loess, red slate, basalt, granite and gravels. The white wines produced in the region tend to be dry and more full-bodied than in other regions of Germany. ",
        },
    },
    {
        "country": "DE",
        "name": "Rheingau",
        "synonyms": ["Rhinegau"],
        "description": {
            "default": "",
            "sommelier": "Rheingau has 3.200 hectares of vineyards, planted with 85% of white grapes. It is is one of the most famous and distinguished wine regions of the world. The Rhine Valley is practically one long hillside on the northern bank of the river. The Taunus Hills provide natural protection from cold winds and torrential rainfall. The climate has minimal winds thanks to protective forests around the towns of Wiesbaden, Rudesheim and Geisenheim. The winters are mild and the summers are warm. The vineyards benefit from the heat-retaining surface of the Rhine River and the reflection from the river back to the vineyards. Riesling thrives particularly well in the dry, stony south-facing slopes. It also survives cold winter days and uses the long ripening period to develop fine fruit acids and aromas. The Spatlese (late harvest) style originates from the Rheingau, already as early as  1775!",
            "julie": "The Rheingau region is stretches from Lorch to the East to Wiesbaden to the West, on the northern shore of the Rhine River.  Riesling represents 80% of the total plantings in Rheingau. Soil in the upper slope vineyards is dominated by slate, whereas the lower vineyards closer to the water contain a mixture of clay, loess, alluvial sand and red slate. Rheingau Riesling tend to be intense, concentrated with a racy acidity. On the western end of the Rheingau, to the northwest of Rüdesheim, lies the village of Assmannshausen. Assmannshausen is the Rheingau’s center for red wine production and  Spätburgunder (Pinot Noir) being the most planted red grape in the region.",
        },
    },
    {
        "country": "DE",
        "name": "Rheinhessen",
        "synonyms": ["Rheinhesse"],
        "description": {
            "default": "",
            "sommelier": "Rheinhessen is Germany’s largest wine region with 26.800 hectares of vineyards. It lies in a valley of gentle rolling hills, south of the city of Mainz in the Frankfurt area. The climate is mild with protective hills and forests, long sun hours and little rainfall. It is thus one of Germany’s warmest regions and one of the driest regions in Central Europe. Rheinhessen winegrowers produce modern, uncomplicated, soft and easy drinking wines as well as top-quality products. The focus is on Riesling, Muller-Thurgau (Rivaner), Dornfelder, Silvaner,  Grauburgunder (Pinot Gris) and  Spatburgunder (Pinot Noir). Loess, limestone and loam, often mixed with sand or gravel, are the main soil types. The rolling hills of Rheinhessen are bordered by the Nahe and Rhine Rivers. Steep vineyard sites are confined to small areas near Bingen and south of Mainz along the Rhein Terrasse.",
            "julie": "",
        },
    },
    {
        "country": "DE",
        "name": "Saale-Unstrut",
    },
    {
        "country": "DE",
        "name": "Saxony",
    },
    {
        "country": "DE",
        "name": "Württemberg",
        "description": {
            "default": "",
            "sommelier": "Württemberg has 11.100 hectares under vine. It is known as Germany's premier red wine region with nearly 70 percent that is planted with red grape varieties. The climate is mild with minimal wind. The rivers help temper the climate. The summers are hot and dry. The soils are varied and include shell-limestone, marl, loess and clay. Württemberg is east of the Rhine and Baden, between the Tauber Valley and the foothills of the Swabian Jura. The vineyards are located primarily along the valleys of the Neckar River and its tributaries, north and east of Stuttgart. The Black Forest and Swabian Jura buffer the vineyards from strong, cold winds and excessive rain. Württemberg is one of only a few places in the world that grows the Trollinger grape, and most of it is consumed locally. There are many steep slope vineyards in these valleys and often the sites are terraced and can only be tended by hand.",
            "julie": "",
        },
    },
    {
        "country": "GR",
        "name": "Aegean islands",
        "subregions": [
            {"name": "Crete"},
            {"name": "Limnos"},
            {"name": "Paros"},
            {"name": "Rhodes"},
            {"name": "Samos"},
            {"name": "Santorini"},
        ],
    },
    {
        "country": "GR",
        "name": "Central Greece",
        "subregions": [
            {"name": "Attica"},
            {
                "name": "Epirus",
                "subregions": [{"name": "Zitsa"}],
            },
            {
                "name": "Thessaly",
                "subregions": [{"name": "Nea Anchialos"}, {"name": "Rapsani"}],
            },
        ],
    },
    {
        "country": "GR",
        "name": "Ionian Islands",
        "subregions": [
            {
                "name": "Kefalonia",
            }
        ],
    },
    {
        "country": "GR",
        "name": "Macedonia",
        "subregions": [
            {"name": "Amyntaion"},
            {"name": "Goumenissa"},
            {
                "name": "Naousa",
                "synonyms": ["Naoussa", "Naoysa"],
            },
            {
                "name": "Imathia",
            }
        ],
    },
    {
        "country": "GR",
        "name": "Peloponnesus",
        "subregions": [
            {"name": "Mantineia"},
            {"name": "Nemea"},
            {"name": "Patras"},
        ],
    },
    {
        "country": "HU",
        "name": "Balaton",
        "subregions": [
            {"name": "Badacsony"},
            {"name": "Balaton-felvidék"},
            {"name": "Balatonboglár"},
            {"name": "Balatonfüred-Csopak"},
            {"name": "Nagy-Somló"},
            {"name": "Zala"},
        ],
    },
    {
        "country": "HU",
        "name": "Duna",
        "subregions": [
            {"name": "Csongrád"},
            {"name": "Hajós-Baja"},
            {"name": "Kunság"},
        ],
    },
    {
        "country": "HU",
        "name": "Eger",
        "subregions": [
            {"name": "Bükk"},
            {"name": "Eger"},
            {"name": "Észak-Dunántúl"},
            {"name": "Etyek-Buda"},
            {"name": "Mátra"},
            {"name": "Mór"},
            {"name": "Neszmély"},
            {"name": "Pannonhalma"},
        ],
    },
    {
        "country": "HU",
        "name": "Pannon",
        "subregions": [
            {"name": "Pécs"},
            {"name": "Szekszárd"},
            {"name": "Tolna"},
            {"name": "Villány"},
        ],
    },
    {
        "country": "HU",
        "name": "Sopron",
    },
    {
        "country": "HU",
        "name": "Tokaj",
    },
    {
        "country": "IT",
        "name": "Apulia",
        "synonyms": [
            "Puglia",
            "Pouilles",
            "Apulien",
        ],
        "subregions": [
            {"name": "Gioia del Colle"},
            {"name": "Bianco di Locorotondo e Martina Franca"},
            {
                "name": "Manduria",
                "synonyms": ["Primitivo di Manduria"],
            },
            {"name": "Salice Salentino"},
            {
                "name": "Squinzano",

            },
            {
                "name": "Brindisi",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Apulia, the heel of the boot of Italy, is located near the Adriatic and Ionian seas, in the south-east of Italy, and is the least mountainous region in the country. Apulia’s mass production was historically devoted to the base wines for vermouth, bulk blending material and distillation. Today, even though the overall quality of the wines produced has increased, only approximately 7% of the total production is sold at DOC or DOCG level. Negroamaro is the most cultivated red grape in the region and produces powerful and full bodied red wines. In the North of Puglia, the Nero di Troia grape variety produces aromatic and tannic wines. The third major red grape of Apulia is Primitivo, which is genetically identical to Zinfandel from the US. ",
        },
    },
    {
        "country": "IT",
        "name": "Calabria",
        "subregions": [
            {"name": "Bivongi"},
            {"name": "Cirò"},
            {"name": "Lamezia"},
            {"name": "Melissa"},
            {"name": "Sant'Anna di Isola Capo Rizzuto"},
            {"name": "Savuto"},
            {"name": "Scavigna"},
            {"name": "Terre di Cosenza"},
        ],
    },
    {
        "country": "IT",
        "name": "Abruzzo",
        "synonyms": ["Abruzzi", "Abruzzen"],
        "subregions": [
            {"name": "Montepulciano d'Abruzzo"},
        ],
    },
    {
        "country": "IT",
        "name": "Lazio",
        "synonyms": ["Latium"],
        "subregions": [
            {"name": "Cannellino di Frascati"},
            {"name": "Cesanese del Piglio"},
            {"name": "Cerveteri"},
            {"name": "Frascati"},
            {"name": "Marino"},
            {"name": "Montecompatri-Colonna"},
            {"name": "Nettuno"},
            {"name": "Velletri"},
        ],
    },
    {
        "country": "IT",
        "name": "Molise",
        "synonyms": ["Molize"],
    },
    {
        "country": "IT",
        "name": "Campania",
        "subregions": [
            {
                "name": "Avellino",
                "subregions": [
                    {"name": "Falanghina"},
                ],
            },
            {
                "name": "Benevento",
                "subregions": [
                    {"name": "Falanghina"},
                    {"name": "Solopaca"},
                ],
            },
            {"name": "Napoli"},
            {"name": "Salerno"},
            {
                "name": "Irpinia",
                "subregions": [
                    {"name": "Taurasi"},
                ],
            },
            {
                "name": "Taburno",
                "synonyms": ["Taburno", "Aglianico del Taburno"],
            },
            {
                "name": "Sannio",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Naples, the capital of Campania, is a World Heritage Site and the largest and most important city in Southern Italy. The region has a very long history of winemaking and today, the ancient red varieties Aglianico and Piedirosso (“red feet”) and the white Falanghina, Greco, and Fiano comprise a majority of the Campanian DOC wines. Aglianico is a tannic, high-acid grape grape variety that has the capacity to produce long-lived red wines. Aglianico shines as a varietal wine in Taurasi DOCG and Aglianico del Taburno DOCG. The white DOCG wines of Campania are Greco di Tufo and Fiano di Avellino. The Fiano di Avellino DOCG wines are produced from a minimum 85% the Fiano grape that gives rich,  full-bodied and aged-worthy white wines. Greco di Tufo DOCG must me made from a minimum of 85% of Greco variety, a lighter but more intensely aromatic grape than Fiano. Falanghina is another qualitative grape of the region that is also worth a mention. ",
        },
    },
    {
        "country": "IT",
        "name": "Emilia-Romagna",
        "synonyms": ["Emilia Romagna"],
        "subregions": [
            {"name": "Colli Cesenate"},
            {"name": "Sangiovese Superiore di Romagna"},
            {"name": "Trebbiano di Romagna"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Emilia-Romagna region are world-renowned is the home of Parmigiano-Reggiano, Prosciutto di Parma, and Modena’s Balsamic vinegar. The region is also home to tow DOCGs for wine : Romagna Albana, Italy’s first white wine DOCG since 1987, and Colli Bolognesi Pignoletto DOCG awarded in 2011. Emilia Romagna is, however, most famous for its production of Lambrusco sparkling red wines made from various subvarieties of the Lambrusco variety. ",
        },
    },
    {
        "country": "IT",
        "name": "Liguria",
        "subregions": [
            {
                "name": "Cinque Terre",
            }
        ],
    },
    {
        "country": "IT",
        "name": "Lombardy",
        "synonyms": ["Lombardia"],
        "subregions": [
            {"name": "Botticino"},
            {"name": "Capriano del Colle"},
            {"name": "Casteggio"},
            {"name": "Cellatica"},
            {"name": "Curtefranca"},
            {"name": "Franciacorta"},
            {"name": "Garda Colli Mantovani"},
            {"name": "Garda Lombardy"},
            {"name": "Lambrusco Mantovano"},
            {
                "name": "Lombardy IGTs",
                "subregions": [
                    {"name": "Alpi Retiche IGT"},
                    {"name": "Benaco Bresciano IGT"},
                    {"name": "Bergamasca IGT"},
                    {"name": "Provincia di Pavia IGT"},
                    {"name": "Sebino IGT"}
                ]
            },
            {"name": "Lugana"},
            {"name": "Montenetto di Brescia IGT"},
            {"name": "Moscato di Scanzo"},
            {
                "name": "Oltrepo Pavese",
                "subregions": [
                    {"name": "Bonarda dell'Oltrepo Pavese"},
                    {"name": "Buttafuoco dell'Oltrepo Pavese"},
                    {"name": "Oltrepo Pavese Metodo Classico"},
                    {"name": "Oltrepo Pavese Pinot Grigio"},
                    {"name": "Pinot Nero dell'Oltrepo Pavese"},
                    {"name": "Sangue di Giuda dell'Oltrepo Pavese"}
                ]
            },
            {"name": "Riviera del Garda Classico"},
            {"name": "San Colombano al Lambro"},
            {"name": "San Martino della Battaglia"},
            {"name": "Terre del Colleoni"},
            {"name": "Valcalepio"},
            {
                "name": "Valtellina",
                "subregions": [
                    {"name": "Sforzato di Valtellina"},
                    {"name": "Valtellina Superiore"}
                ]
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Lombardy is most famous for the quality of its traditional method sparkling wines sold under the Franciacorta and the Oltrepò Pavese metodo Classico DOCGs.  To the north of Franciacorta is Valtellina, Lombardy’s most important zone for red wines and considered an “heroic wine zone” for the challenging condition of its grape growing, making mechanisation impossible. Chiavennasca, the local names given to the Nebbiolo grape, provides a lighter style than in neighbouring Piemonte, often harvest from grapes grown in elevated terraces held together by stone walls.  ",
        },
    },
    {
        "country": "IT",
        "name": "Marche",
        "synonyms": ["Marches", "Le Marche", "De Marken"],
        "subregions": [
            {"name": "Castelli di Jesi"},
            {"name": "Conero"},
            {"name": "Piceno"},
        ],
    },
    {
        "country": "IT",
        "name": "Aosta Valley",
        "synonyms": ["Valle d'Aosta"],
    },
    {
        "country": "IT",
        "name": "Piedmont",
        "synonyms": ["Piemonte"],
        "subregions": [
            {
                "name": "Acqui",
                "synonyms": ["Acqui Terme", "Brachetto d'Acqui", "Barbera d'Acqui"],
            },
            {"name": "Asti"},
            {"name": "Colli Tortonesi"},
            {"name": "Gattinara"},
            {
                "name": "Gavi",
                "synonyms": ["Cortese di Gavi"],
            },
            {"name": "Ghemme"},
            {
                "name": "Langhe",
                "subregions": [
                    {"name": "Roero"},
                    {"name": "Alba"},
                    {"name": "Barolo"},
                    {"name": "Barbaresco"},
                    {
                        "name": "Dogliani",
                    }
                ]
            },
            {"name": "Monferrato"},
            {"name": "Nizza"},
            {"name": "Ovada"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The region of Piedmont produces some of the finest wines in Italy and is considered, with Tuscany, as one of Italy’s most significant wine regions. Piedmont means “the foot the mountain” and is located at the foothills of the Appennines and the Alps. Most of the vineyards are planted south of the Po River Valley in the province of Asti, Alessandria and Cuneo. Piedmont experiences a continental climate to which the Alps provide a barrier from the rain. The region is composed of various soils such as calcareous marl, sandstone, clay and sand that are an important asset to viticulture. The region produces a broad range of wines – sparkling, sweet, white, red – from various grape varieties such as Nebbiolo, Barbera, Dolcetto, Arneis and Moscato. ",
        },
    },
    {
        "country": "IT",
        "name": "Sardinia",
        "synonyms": ["Sardegna"],
        "subregions": [
            {"name": "Cagliari"},
            {"name": "Cannonau"},
            {"name": "Monti"},
            {
                "name": "Ogliastra",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Sardinia is an Italian island located south of Corsica in the middle of the Mediterranean sea. The island is well known for its refreshing aromatic white wines sold under the Vermentino di Gallura DOCG and for its powerful, sun kissed red wines made from the grape varities Cannonau (Grenache) and Carignano. ",
        },
    },
    {
        "country": "IT",
        "name": "Sicily",
        "synonyms": ["Sicilia"],
        "subregions": [
            {"name": "Etna"},
            {"name": "Noto"},
            {"name": "Pantelleria"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Sicily is one of Italy’s largest producers of wine, usually surpassed in volume only by Veneto. Historically, Sicily has been producing very little wine at the DOC level and a lot of the wine produced are low quality bulk wines. However, Sicily is well-suited to quality winemaking and more and more premium wines are being born on the island. The volcanic region of Etna, in the east of the island, is now producing some of the finest dry white and red wines of the country. The island has a wealth of indigenous grapes uniquely suited to its warm, dry climate. White grapes include the native Catarratto, Inzolia, Grecanico, Carricante, and Grillo. Zibibbo (Muscat of Alexandria) and Malvasia are also commonly encountered in Sicily. Native red grapes include Nero d’Avola (Calabrese), Frappato, Perricone, Nerello Mascalese and Nerello Cappuccio.",
        },
    },
    {
        "country": "IT",
        "name": "Tuscany",
        "synonyms": ["Toscana"],
        "subregions": [
            {"name": "Bolgheri"},
            {
                "name": "Chianti",
                "subregions": [
                    {
                        "name": "Chianti Classico",
                    }
                ],
            },
            {"name": "Colli Apuani"},
            {"name": "Colli Etruria Centrale"},
            {"name": "Colline Lucchesi"},
            {"name": "Elba"},
            {
                "name": "Montalcino",
                "synonyms": ["Brunello di Montalcino"],
            },
            {"name": "Montescudaio"},
            {"name": "Parrina"},
            {"name": "Pitigliano"},
            {"name": "San Gimignano"},
            {"name": "Scansano"},
            {"name": "Val di Chiana"},
            {"name": "Val di Cornia"},
            {"name": "Valdinievole"},
            {"name": "Valle di Arbia"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The first DOC and DOCG zones to be delimited in Italy were Tuscan, with the famous wine region of Chianti being first delimited in 1716. Tuscany is known for its unique beauty made of hills covered in vineyards, olive tree groves and wheat fields. Tuscany is home to 11 DOCGs – Denominazione di origine controllata e garantita – the highest appellation level for wine in Italy. Tuscany trails only Piedmont and Veneto in the number of its DOCG zones. Tuscany overall enjoys a dry, Mediterranean climate but some parts of the region can experience more extreme weather patterns with very hot Summers and harsh Winters. Elevation and soil types also vary greatly within the region. Sangiovese is the main red grape of Tuscany – light in colour, naturally high in acidity and tannins with aromas of sour cherries and wild herbs – it is the main component of the wines of Chianti DOCG, Chianti Classico DOCG, Vino Nobile di Montepulciano DOCG and the only grape permitted for the production of Brunello di Montalcino DOCG. 85% of the wines produced in Tuscany are red and other grape varieties commonly found in the region include Colorino, Canaiolo, Cabernet Sauvignon, Merlot and Syrah.",
        },
    },
    {
        "country": "IT",
        "name": "Umbria",
        "subregions": [
            {"name": "Montefalco"},
            {"name": "Orvieto"},
            {"name": "Torgiano"},
        ],
    },
    {
        "country": "IT",
        "name": "Trevenezie",
        "synonyms": ["Tre Venezie", "delle Venezie"],
        "subregions": [
            {
                "name": "Veneto",
                "subregions": [
                    {"name": "Arcole"},
                    {"name": "Bagnoli"},
                    {"name": "Bardolino"},
                    {"name": "Bianco di Custoza"},
                    {"name": "Breganze"},
                    {"name": "Colli Berici"},
                    {"name": "Colli di Conegliano"},
                    {"name": "Colli Euganei"},
                    {"name": "Gambellara"},
                    {"name": "Lessini Durello"},
                    {"name": "Lison Pramaggiore"},
                    {"name": "Lugana"},
                    {"name": "Montgello e Colli Asolani"},
                    {"name": "Piave"},
                    {"name": "Soave"},
                    {
                        "name": "Valdadige",
                        "synonyms": ["Etschtaler"],
                    },
                    {"name": "Valpolicella"},
                ],
                "description": {
                    "default": "",
                    "sommelier": "",
                    "julie": "Veneto produces more wine than any other region in Italy, yet much of  its production is at inexpensive price point with the bulk of it being made of Pinot Grigio and sparkling prosecco. However, Veneto also produces some of the most sought-after wines of the countries including the famous Amarone della Valpolicella, a red wine made from grapes partially dried. Other noteworthy wines of the region include the Valpolicella and Bardolino DOCs that produce bright, mouth-watering red wine with cherry and bitter almond flavours from the Corvina and Rondinella grape varieties. The Soave DOC, the most important white wine zone of the region, planted with Garganega, Trebbiano di Soave and Chardonnay offers some dry white wines that range from light, crisp and simple to rich, complex and mineral. Sweet wines made from dried grapes are also produced in the regions of Valpolicella and Soave and  are labelled as “Recioto”. ",
                },
            },
            {
                "name": "Friuli-Venezia Giulia",
                "synonyms": ["Friuli", "Friuli Venezia Giulia"],
                "subregions": [
                    {"name": "Carso"},
                    {
                        "name": "Collio",
                        "synonyms": ["Collio Goriziano"],
                    },
                    {
                        "name": "Friuli Aquileia",
                        "synonyms": ["Aquileia"],
                    },
                    {"name": "Friuli Isonzo"},
                    {"name": "Friuli Grave"},
                    {"name": "Latisana"},
                    {"name": "Lison-Pramaggiore"},
                    {"name": "Ramandolo"},
                ],
                "description": {
                    "default": "",
                    "sommelier": "",
                    "julie": "The winemaking tradition of Friuli-Venezia Giulia is highly influenced from neighbouring Slavic, German, and Italian cultures. The introduction of controlled cold fermentations in in stainless steel vats in the 1960s, coupled with the region’s moderate temperatures, led to the Friulian style: crisp, aromatic, fruit-driven varietal white wines designed for quick consumption. Pinot Bianco, Chardonnay, Pinot Grigio and Sauvignon blanc are very popular international white grapes in the region. Friuli is also rich in local grape varieties which are attracting more and more interest : Verduzzo Gialla, Picolit, Friulano, Ribolla Gialla and Malvasia Istriana are great white examples while Schioppettino, Refosco, Terrano and Pignolo are indigenous red grape varieties that produces some excellent quality wines. Today, producers are also continually experimenting and Modern Friulian whites can be blended, barrel-fermented, powerful and lush rather than lean. Skin-contact white wines have also gained in popularity. Despite the fact that Friuli receives the most acclaim for its white wines, a significant part of the region is planted with Merlot, Cabernet Franc and Cabernet Sauvignon that can be sold as varietal wines or blended. The winemaking tradition of Friuli-Venezia Giulia is highly influenced from neighbouring Slavic, German, and Italian cultures. The introduction of controlled cold fermentations in in stainless steel vats in the 1960s, coupled with the region’s moderate temperatures, led to the Friulian style: crisp, aromatic, fruit-driven varietal white wines designed for quick consumption. Pinot Bianco, Chardonnay, Pinot Grigio and Sauvignon blanc are very popular international white grapes in the region. Friuli is also rich in local grape varieties which are attracting more and more interest : Verduzzo Gialla, Picolit, Friulano, Ribolla Gialla and Malvasia Istriana are great white examples while Schioppettino, Refosco, Terrano and Pignolo are indigenous red grape varieties that produces some excellent quality wines. Today, producers are also continually experimenting and Modern Friulian whites can be blended, barrel-fermented, powerful and lush rather than lean. Skin-contact white wines have also gained in popularity. Despite the fact that Friuli receives the most acclaim for its white wines, a significant part of the region is planted with Merlot, Cabernet Franc and Cabernet Sauvignon that can be sold as varietal wines or blended. The winemaking tradition of Friuli-Venezia Giulia is highly influenced from neighbouring Slavic, German, and Italian cultures. The introduction of controlled cold fermentations in in stainless steel vats in the 1960s, coupled with the region’s moderate temperatures, led to the Friulian style: crisp, aromatic, fruit-driven varietal white wines designed for quick consumption. Pinot Bianco, Chardonnay, Pinot Grigio and Sauvignon blanc are very popular international white grapes in the region. Friuli is also rich in local grape varieties which are attracting more and more interest : Verduzzo Gialla, Picolit, Friulano, Ribolla Gialla and Malvasia Istriana are great white examples while Schioppettino, Refosco, Terrano and Pignolo are indigenous red grape varieties that produces some excellent quality wines. Today, producers are also continually experimenting and Modern Friulian whites can be blended, barrel-fermented, powerful and lush rather than lean. Skin-contact white wines have also gained in popularity. Despite the fact that Friuli receives the most acclaim for its white wines, a significant part of the region is planted with Merlot, Cabernet Franc and Cabernet Sauvignon that can be sold as varietal wines or blended.",
                },
            },
            {
                "name": "Trentino-Alto Adige",
                "synonyms": [
                    "Trentino-South Tyrol",
                    "Trentino-Südtirol",
                    "Trentino Alto Adige",
                ],
                "subregions": [
                    {
                        "name": "South Tyrol",
                        "synonyms": ["Alto Adige", "Südtirol"],
                    },
                    {"name": "Trentino"},
                ],
                "description": {
                    "default": "",
                    "sommelier": "",
                    "julie": "The Trentino-Alto Adige region is subdivided into the Italian-speaking Trentino in the south and the German-speaking Alto-Adige or Südtirol, in the north. Trentino-Alto Adige is primarily known for its white wines, but the region supplies a larger quantity of reds than whites. Schiava (Vernatsch) is the predominant grape and produces light red wines. The Lagrein grape is native to Trentino and produces denser, spicier wines than Schiava. Pinot Nero (Pino Noir) is also becoming increasingly important in the region, especially in the South of the region. Other interesting res grapes of the region include Teroldego and Marzemino. ",
                },
            },
        ],
        "description": { "default": "", "sommelier": "", "julie": "" },
    },
    {
        "country": "IT",
        "name": "Basilicata",
        "synonyms": ["Basilicate"],
        "subregions": [
            {
                "name": "Aglianico del Vulture",
                "synonyms": ["Aglianico del Vulture Superiore", "Vulture"],
            }
        ],
    },
    {
        "country": "LV",
        "name": "Sabile",
    },
    {
        "country": "LT",
        "name": "Anykščių vynas",
    },
    {
        "country": "LT",
        "name": "Mėmelio vynas",
    },
    {
        "country": "LU",
        "name": "Moselle Valley",
    },
    {
        "country": "MD",
        "name": "Bardar",
    },
    {
        "country": "MD",
        "name": "Codri",
    },
    {
        "country": "MD",
        "name": "Hîncești",
    },
    {
        "country": "MD",
        "name": "Purcari",
    },
    {
        "country": "ME",
        "name": "Crmnica",
    },
    {
        "country": "ME",
        "name": "Plantaže",
    },
    {
        "country": "NL",
        "name": "Groesbeek",
    },
    {
        "country": "MK",
        "name": "Povardarie",
    },
    {
        "country": "MK",
        "name": "Skopsko vinogorje",
    },
    {
        "country": "MK",
        "name": "Tikveš",
    },
    {
        "country": "NO",
        "name": "Mostly",
    },
    {
        "country": "NO",
        "name": "Sognefjord",
    },
    {
        "country": "PL",
        "name": "Dolny Śląsk",
    },
    {
        "country": "PL",
        "name": "Kazimierz Dolny",
    },
    {
        "country": "PL",
        "name": "Małopolska",
    },
    {
        "country": "PL",
        "name": "Podkarpacie",
    },
    {
        "country": "PL",
        "name": "Warka",
    },
    {
        "country": "PL",
        "name": "Zielona Góra",
    },
    {
        "country": "PT",
        "name": "Lisboa",
        "synonyms": ["Lisbon"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The coastal Lisboa IGP covers the area south of Beiras and runs up to Portugal’s capital city. Lisboa contains nine individual DOPs : Bucelas, Colares, Carcavelos, Arruda, Torres Vedas, Alenquer, Óbidos, Lourinhã and Encostas d’Aire. Lourinhå produces aguardente ",
        },
    },
    {
        "country": "PT",
        "name": "Península de Setúbal",
        "synonyms": ["Setúbal", "Setúbal Peninsula"],
        "subregions": [
            {
                "name": "Palmela",
            }
        ],
    },
    {
        "country": "PT",
        "name": "Alentejo",
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The Alentejo DOP is located withing the Alentejano IGP that covers 30% of Portugal’s landmass. The DOP includes 8 subzones : Moura, Granja-Amareleja, Évora, Vidigueira, Reguengos, Redondo, Borba, and Portalegre. Red wine production exceeds that of whites and Trincadeira is the most planted variety. The region is also known for its plantation of cork tree and its cork production. ",
        },
    },
    {
        "country": "PT",
        "name": "Bairrada",
    },
    {
        "country": "PT",
        "name": "Bucelas",
    },
    {
        "country": "PT",
        "name": "Carcavelos",
    },
    {
        "country": "PT",
        "name": "Colares",
    },
    {
        "country": "PT",
        "name": "Dão",
    },
    {
        "country": "PT",
        "name": "Lagoa",
    },
    {
        "country": "PT",
        "name": "Lagos",
    },
    {
        "country": "PT",
        "name": "Madeira",
    },
    {
        "country": "PT",
        "name": "Portimão",
    },
    {
        "country": "PT",
        "name": "Porto e Douro",
        "synonyms": ["Douro", "Douro Valley", "Porto"],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The Douro was Portugal’s first demarcated wine region and is a UNESCO World Heritage Site. The Douro river and its tributaries have carved deep valleys through the granitic Marão and Montemuro Mountains, and vineyards run from the riverside up the terraced, precipitous slopes. Schist is in abundance throughout the zone. The Douro Valley experiences a continental climate of severely hot summers and cold winters. The region’s craggy mountains act as barriers to the humid Atlantic winds, and the Douro becomes progressively drier and hotter toward the Spanish border. There are three subzones in Douro; Baixo Corgo to the west has the highest density of plantings, Cima Corgo has the highest total vineyard acreage, and Douro Superior, which stretches to the Spanish border, is the largest, most arid, and most sparsely planted region in Douro. The region is famous for the production of fortified wines known as Port wines that represent about 50% of the total production. Table wines are produced as Douro DOP and can be white, rosé, red, sweet and sparkling.",
        },
    },
    {
        "country": "PT",
        "name": "Setúbal",
    },
    {
        "country": "PT",
        "name": "Tavira",
    },
    {
        "country": "PT",
        "name": "Vinhos Verdes",
        "synonyms": ["Vinho Verde", "Minho"],
    },
    {
        "country": "RO",
        "name": "Banat",
        "subregions": [
            {"name": "Arad"},
            {"name": "Jamu Mare"},
            {"name": "Măderat"},
            {"name": "Miniș"},
            {"name": "Moldova Nouă"},
            {"name": "Recaș"},
            {"name": "Silagiu"},
            {"name": "Teremia"},
            {"name": "Tirol"},
        ],
    },
    {
        "country": "RU",
        "name": "Caucasus",
    },
    {
        "country": "RU",
        "name": "Krasnodar",
    },
    {
        "country": "RU",
        "name": "Stavropol",
    },
    {
        "country": "RS",
        "name": "Banat",
    },
    {
        "country": "SK",
        "name": "Malokarpatská",
    },
    {
        "country": "SK",
        "name": "Južnoslovenská",
    },
    {
        "country": "SK",
        "name": "Nitrianska",
    },
    {
        "country": "SK",
        "name": "Stredoslovenská",
    },
    {
        "country": "SK",
        "name": "Tokaj",
    },
    {
        "country": "SK",
        "name": "Východoslovenská",
    },
    {
        "country": "SK",
        "name": "The whole of southern Slovakia",
    },
    {
        "country": "SI",
        "name": "Podravje",
    },
    {
        "country": "SI",
        "name": "Posavje",
    },
    {
        "country": "SI",
        "name": "Primorska",
    },
    {
        "country": "ES",
        "name": "Andalusia",
        "subregions": [
            {"name": "Condado de Huelva"},
            {
                "name": "Jerez-Xeres-Sherry",
                "synonyms": ["Jerez", "Xeres", "Sherry"],
            },
            {"name": "Málaga and Sierras de Málaga"},
            {"name": "Manzanilla"},
            {"name": "Montilla-Moriles"},
        ],
    },
    {
        "country": "ES",
        "name": "Aragón",
        "synonyms": ["Aragon"],
        "subregions": [
            {"name": "Calatayud"},
            {"name": "Campo de Borja"},
            {
                "name": "Campo de Cariñena",
                "synonyms": ["Cariñena"],
            },
            {"name": "Cava"},
            {"name": "Somontano"},
        ],
    },
    {
        "country": "ES",
        "name": "Balearic Islands",
        "subregions": [
            {"name": "Binissalem-Mallorca"},
            {"name": "Plà i Llevant"},
        ],
    },
    {
        "country": "ES",
        "name": "Basque Country",
        "synonyms": [
            "Euskadi",
            "País Vasco",
            "La Comunidad Autonoma del País Vasco",
            "El País Vasco",
        ],
        "subregions": [
            {
                "name": "Alava",
                "synonyms": [
                    "Álava", 
                    "Alavan Txakolina", 
                    "Alavan Txakoli",
                    "Arabako Txakolina",
                    "Araba",
                ],
            },
            {
                "name": "Biscay",
                "synonyms": [
                    "Bizkaiko",
                    "Bizkaiko Txakolina",
                    "Biscay",
                    "Biscayan Txakoli",
                ],
            },
            {"name": "Cava"},
            {
                "name": "Getaria",
                "synonyms": [
                    "Getariako Txakolina",
                    "Getaria",
                    "Getarian Txakoli",
                    "Txakoli de Getaria",
                ],
            },
        ],
    },
    {
        "country": "ES",
        "name": "Canary Islands",
        "subregions": [
            {"name": "Abona"},
            {"name": "El Hierro"},
            {"name": "Gran Canaria"},
            {"name": "La Gomera"},
            {"name": "La Palma"},
            {"name": "Lanzarote"},
            {"name": "Tacoronte-Acentejo"},
            {"name": "Valle de Güímar"},
            {"name": "Valle de la Orotava"},
            {"name": "Ycoden-Daute-Isora"},
        ],
    },
    {
        "country": "ES",
        "name": "Castile and León",
        "synonyms": [
            "Castilla y León", 
            "Castilla y Leon", 
            "Castile-Leon",  
            "Espumosos de Castilla y León"
        ],
        "subregions": [
            { "name": "Arlanza" },
            { "name": "Arribes del Duero", "synonyms": ["Arribes"] },
            { "name": "Bierzo" },
            { "name": "Cava" },
            { "name": "Cebreros" },
            { "name": "Cigales" },
            { "name": "Castilla y Leon VT", "synonyms": ["Vino de la Tierra Castilla y León"] }, # not sure what to do about this one
            { "name": "León", "synonyms": ["Tierra de León"] },
            { "name": "Ribera del Duero" },
            { "name": "Rueda" },
            { "name": "Sardon de Duero" },
            { "name": "Sierra de Salamanca" },
            { "name": "Zamora", "synonyms": ["Tierra del Vino de Zamora"] },
            { "name": "Toro" },
            { "name": "Valles de Benavente" },
            { "name": "Valtiendas" },
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Castilla y León is located in north central Spain. The region is crossed by the Duero River that flows westward through the centre of the region and passes the DOs of Ribera del Duero, Toro, Tierra del Vino de Zamora and Arribes on its way to Portugal. Other DOs of the region include Arlanza, Cigales, Leòn and Bierzo. The main red grape varieties of Castilla y León are Tempranillo and Mencia while the main white grape varieties are Verdejo, Viura and Godello. ",
        },
    },
    {
        "country": "ES",
        "name": "Castile–La Mancha",
        "synonyms": [
            "Castilla-La Mancha", 
            "Castilla La Mancha", 
            "Castila la Mancha",
            "Vino de la Tierra Castilla"
        ],
        "subregions": [
            {"name": "Almansa"},
            {
                "name": "Guijoso",
                "synonyms": ["Pago Guijoso"],
            },
            {"name": "La Mancha"},
            {"name": "Manchuela"},
            {"name": "Méntrida"},
            {"name": "Mondéjar"},
            {"name": "Ribera del Júcar"},
            {
                "name": "Toledo",
                "subregions": [
                    {"name": "Dominio de Valdepusa"},
                ]
            },
            {"name": "Uclés"},
            {"name": "Valdepeñas"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Castilla-La-Mancha is home to La Mancha DO, Europe’s largest single demarcated wine region. The principal grapes of the region are Cencibel (Tempranillo) and Airén, which thrive in La Mancha’s hot, dry environment. ",
        },
    },
    {
        "country": "ES",
        "name": "Catalonia",
        "synonyms": ["Catalunya", "Cataluña"],
        "subregions": [
            {"name": "Alella"},
            {"name": "Conca de Barberà"},
            {"name": "Costers del Segre"},
            {"name": "Empordà"},
            {"name": "Montsant"},
            {
                "name": "Penedès",
                "subregions": [
                    {"name": "Cava"},
                ],
            },
            {"name": "Pla de Bages"},
            {"name": "Priorat"},
            {"name": "Tarragona"},
            {"name": "Terra Alta"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Catalonia, or Catalunya in the Catalan language, is located very near to France’s Roussillon region. Catalunya is the centre of production for Cava wines, a Spanish traditional method sparkling wine that founds its origin within the sub-region of Penedes. The region has a Mediterranean climamte and is home to 12 DOs (Denominacion de Origen) and 1 DOCa, the highest distinction for a wine region in Spain. Catalonia produces a wide range of wines from dry to sweet, white to red, sparkling and oxidative. Elevation, distance from the sea and geology as well as the choice of grape varieties are all factors that have an impact on the styles of the wines of the region. Notable regions include Priorat DOCa, Conca del Barvera DO, Costers del Segre DO, Penedes DO, etc.",
        },
    },
    {
        "country": "ES",
        "name": "Extremadura",
        "subregions": [
            {"name": "Cava"},
            {"name": "Ribera del Guadiana"},
        ],
    },
    {
        "country": "ES",
        "name": "Galicia",
        "subregions": [
            {"name": "Monterrey"},
            {"name": "Rías Baixas"},
            {"name": "Ribeira Sacra"},
            {"name": "Ribeiro"},
            {"name": "Valdeorras"},
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Galicia is one of Spain’s greenest region with lush vegetation and forests and is located at the border with Portugal. The region maritime climate is also ideal for the production of crisp white wines as well as fresh rosé and reds. The five DOs of Galicia are Ríais Baixas, Ribeiro, Valdeorras, Ribeira Sacra and Monterrei. Albariño is the most planted grape in the Ríais Baixas DO and represents 96% of the plantings in the region. Ribeiro DO is of the Spain’s oldest wine region and produces white wines made from Treixadura and red wines made from Caiño. In recent years, Ribeira Sacra DO has produced some of Spain’s most sought-after wines.This remote wine region’s best red and wine wines are made from the Mencía, Treixadura and Godello grape varieties. Finally, Valdeorras is Galicia’s easternmost DO and is best known for the quality of its dry white wines made from the Godello grape variety. ",
        },
    },
    {
        "country": "ES",
        "name": "La Rioja",
        "synonyms": ["Rioja"],
        "subregions": [
            {
                "name": "Cava",
            }
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "The region of Rioja is named after the Oja river, a small tributary to the Ebro and was the first Spanish region to be awarded a DOCa (the highest appellation level in Spain), in 1991. The region is located between Haro to the north west to Alfaro in the south east and it is divided in to three subregions : Rioja Alta, Rioja Alavesa, Rioja Oriental. Each of these subregions have a specific climate and soil type that impact the styles of wine produced. Tempranillo is the main grape for the production of red Rioja and is traditionally blended with Mazuelo, Graciano, Garnacha and Maturana Tinta. Viura, also called Macabeo, is the principal white grape for the production of white Rioja. Rioja wines are be labelled as Joven, Crianza, Reserva and Gran Reserva depending on their time of ageing in cask and bottle before release. A small amount of Rioja is also produced as rosé wine and since 2018, the region is also allowed to produce some sparkling wines sold as “vino espumoso de Calidad”. ",
        },
    },
    {
        "country": "ES",
        "name": "Community of Madrid",
        "subregions": [
            {
                "name": "Vinos de Madrid",
            }
        ],
    },
    {
        "country": "ES",
        "name": "Región de Murcia",
        "synonyms": ["Murcia"],
        "subregions": [
            {"name": "Bullas"},
            {"name": "Jumilla"},
            {"name": "Yecla"},
        ],
    },
    {
        "country": "ES",
        "name": "Navarre",
        "subregions": [
            {"name": "Cava"},
            {"name": "Navarra"},
        ],
    },
    {
        "country": "ES",
        "name": "Valencian Community",
        "synonyms": ["Valencia"],
        "subregions": [
            {"name": "Alicante"},
            {"name": "Cava"},
            {"name": "Utiel-Requena"},
            # {
            #     "name": "Valencia DO",
            # },
        ],
        "description": {
            "default": "",
            "sommelier": "",
            "julie": "Valencia is simultaneously the name of the autonomía, its capital  and a DO zone focusing on white wines produced from the local Merseguera grape and other varieties. The other DO zones within the autonomía of Valencia are Alicante and Utiel-Requena. Alicante DO is known Fondillón, a solera-style, oxidative dessert wine produced from overripe Monastrell (Mourvèdre) grapes aged for a minimum of ten years. Utiel-Requena DO red wines are primarily produced from the Bobal grape.",
        },
    },
    {
        "country": "SE",
        "name": "Gutevin",
    },
    {
        "country": "CH",
        "name": "Aargau",
    },
    {
        "country": "CH",
        "name": "Bern",
        "subregions": [
            {"name": "Shores of Lake Biel"},
            {"name": "Shores of Lake Thun"},
        ],
    },
    {
        "country": "CH",
        "name": "Freiburg",
    },
    {
        "country": "CH",
        "name": "Geneva",
        "synonyms": ["Genève", "Genf", "Zeneva"],
        "description": {
            "default": "",
            "sommelier": "Geneva, at the western end of Lac Léman (Lake Geneva), is the second-largest city in Switzerland and the country's third-largest wine producing canton after Valais and Vaud. At 1,400 hectares, Geneva accounts for 10 percent of the country's vineyard area. The climate in Geneva is moderated significantly by the presence of the lake, which prevents summer temperatures from rising dramatically and slows the effects of frost and snow in winter. Such is the impact of Lake Geneva that many shoreline vineyards escape the risk of frost entirely. This makes Geneva one of the warmer viticultural areas of Switzerland. The region has moderate rainfall.",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "Grisons",
    },
    {
        "country": "CH",
        "name": "Neuchâtel",
        "synonyms": ["Neuenburg", "Three Lakes"],
        "description": {
            "default": "",
            "sommelier": "Neuchatel is one of the smaller wine regions of Switzerland, located in the French-speaking western half of the country, north of the much larger Vaud area. Much like its neighbour, Chasselas dominates white plantings here, however Pinot Noir is more significant here. The region is generally referred to as the 'Three Lakes' as the region - and the four AOCs within it - are found on the relatively low-lying, flatter land, centered around the lakes of Morat, Bienne and Neuchatel. Overall, this puts the wine region on what the Swiss refer to as "
            "la plaine"
            " - a relatively flat area of land from Geneva through Bern to Zurich, sandwiched to the north by the Jura and to the south by the Alps. The vineyards here are on relatively low-lying, flatter land, centered around the lakes. The climate is moderated significantly by the presence of the  lakes, which prevent summer temperatures from rising dramatically and also dampen the effects of frost and snow in winter. To maximize the vines' exposure to sunshine, they are mostly planted on the northern banks of the lakes, where the south-easterly aspect brings them warming rays all through the morning and early afternoon.",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "St. Gallen",
    },
    {
        "country": "CH",
        "name": "Schaffhausen",
        "description": {
            "default": "",
            "sommelier": "Schaffhausen is a typical Swiss-German cantonal appellation in the north, producing predominantly Pinot Noir wines in spectacular scenery and with a large German influence in the styles of wines. It has about 480 hectares under vine, with 80% of it being red varieties. The Schaffhausen landscape is divided between two topographical areas: the gently meandering, forest-topped river valleys which characterize the center and east of the canton, and the flatter land to the west close to the German border.",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "Thurgau",
    },
    {
        "country": "CH",
        "name": "Ticino",
        "synonyms": ["Tessin"],
        "description": {
            "default": "",
            "sommelier": "The only Swiss vineyard area on the southern slopes of the Alps, Ticino is exposed to abundant rainfall and generous sunshine and has about 1.100 hectares of vineyards. This climate, with maritime influences, favours the development of Merlot. In climatic terms, Ticino stands out somewhat from other Swiss wine regions thanks to its topography, altitude and latitude. As is fitting for the most-southerly region, it has some of the hottest average summer temperatures. ",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "Valais",
        "synonyms": ["Wallis"],
        "description": {
            "default": "",
            "sommelier": "Valais is the largest Wine region in Switzerland (30% of the total production, 5000 hectares of vineyards) stretching along the upper course of the Rhone, in the heart of the Alps. The climate is dry and sunny on those spectacular terraced vineyards, that go up to 1.100 meters high. Reinforced by strong and hot foehn winds, this microclimate particularly favours the maturation of late-ripening grape varieties found in the region. It is one of the highest wine regions in Europe. It is planted mostly with red grapes like Pinot Noir and Gamay. The Valais terroir is one of the world's most dramatic. The valley benefits from its sheltered position below the high alpine peaks. ertiginous alpine topography also gives the vines in Valais the advantage of emphasized vineyard orientation and many are planted on steep gradients of up to 42 degrees. This steepness, although making it markedly harder to manage and harvest the vines, brings the significant benefits of excellent drainage and increased exposure to sunlight.",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "Vaud",
        "synonyms": ["Waadt", "Vaud wine region", "Vaud wine country"],
        "subregions": [
            {"name": "La Côte"},
            {"name": "Lavaux"},
        ],
        "description": {
            "default": "",
            "sommelier": "Vaud is spread over more than 3.700 hectares and is the second largest wine region in Switzerland, located in the French-speaking southwest of the country. This region is strongly influenced by the proximity of lakes and is full of oenological, historical and cultural jewels. It is the only Swiss wine region to cultivate a majority of white grape varieties, with a focus on Chasselas. The Vaud wine country is divided into four main areas: La Côte stretches out along the western part of Lake Geneva, to Féchy and Mont-sur-Rolle in the centre and municipalities such as Vinzel, Perroy and Aubonne at both sides. The Lavaux region, which has been a UNESCO World Heritage Site since June 2007, extends from Lausanne to Vevey and Montreux.",
            "julie": "",
        },
    },
    {
        "country": "CH",
        "name": "Zürich",
        "synonyms": ["Zurich"],
    },
    {
        "country": "TR",
        "name": "Marmara",
        "synonyms": ["Thrace", "Thracia"],
        "subregions": [
            {
                "name": "Tekirdağ",
                "subregions": [{"name": "Büyükkarıştıran"}, {"name": "Lüleburgaz"}],
            },
            {
                "name": "Kırklareli",
                "subregions": [
                    {"name": "Şarköy"},
                    {"name": "Mürefte"},
                    {"name": "Yazır"},
                    {"name": "Çerkezköy"},
                ],
            },
            {
                "name": "Balıkesir",
                "subregions": [
                    {"name": "Avşa"},
                    {"name": "Marmara Island"},
                    {"name": "Yiğitler"},
                ],
            },
            {
                "name": "Istanbul",
                "subregions": [{"name": "Kemerburgaz"}],
            },
        ],
    },
    {
        "country": "TR",
        "name": "Aegean wine region",
        "subregions": [
            {
                "name": "Çanakkale",
                "subregions": [
                    {"name": "Bozcaada"},
                    {"name": "Gelibolu"},
                    {"name": "Eceabat"},
                ],
            },
            {
                "name": "Manisa",
                "subregions": [{"name": "Akhisar"}, {"name": "Kula"}],
            },
            {
                "name": "Denizli",
                "subregions": [{"name": "Bekilli"}, {"name": "Güney"}],
            },
            {
                "name": "İzmir",
                "subregions": [
                    {"name": "Torbalı"},
                    {"name": "Urla"},
                    {"name": "Kemalpaşa"},
                    {"name": "Selçuk"},
                ],
            },
            {"name": "Isparta"},
            {
                "name": "Muğla",
                "subregions": [{"name": "Bodrum"}],
            },
            {"name": "Burdur"},
            {"name": "Aydın"},
        ],
    },
    {
        "country": "TR",
        "name": "Mediterrenean wine region",
        "subregions": [
            {
                "name": "Antalya",
                "subregions": [{"name": "Elmalı"}],
            },
            {"name": "Mersin"},
        ],
    },
    {
        "country": "TR",
        "name": "Anatolia",
        "subregions": [
            {
                "name": "Mid-southern anatolia",
                "subregions": [
                    {
                        "name": "Nevşehir",
                        "subregions": [
                            {"name": "Ürgüp"},
                            {"name": "Göreme"},
                            {"name": "Gülşehir"},
                        ],
                    },
                    {"name": "Kayseri"},
                ],
            },
            {
                "name": "Mid-northern anatolia",
                "subregions": [
                    {
                        "name": "Ankara",
                        "subregions": [{"name": "Akyurt"}, {"name": "Kalecik"}],
                    },
                    {"name": "Eskişehir"},
                    {"name": "Yozgat"},
                    {"name": "Sivas"},
                    {"name": "Çankırı"},
                ],
            },
            {
                "name": "Mid-eastern anatolia",
                "subregions": [{"name": "Tokat"}, {"name": "Elazığ"}],
            },
            {
                "name": "Southeast anatolia",
                "subregions": [{"name": "Şanlıurfa"}, {"name": "Diyarbakır"}],
            },
        ],
    },
    {
        "country": "UA",
        "name": "Autonomous Republic of Crimea",
    },
    {
        "country": "UA",
        "name": "Kherson Oblast",
    },
    {
        "country": "UA",
        "name": "Mykolaiv Oblast",
    },
    {
        "country": "UA",
        "name": "Odesa Oblast",
    },
    {
        "country": "UA",
        "name": "Zakarpattia Oblast",
    },
    {
        "country": "UA",
        "name": "Zaporizhzhia Oblast",
    },
    {
        "country": "AM",
        "name": "Ararat Valley",
    },
    {
        "country": "AM",
        "name": "Ijevan",
    },
    {
        "country": "AZ",
        "name": "Aghdam",
    },
    {
        "country": "AZ",
        "name": "Baku",
    },
    {
        "country": "AZ",
        "name": "Ganja",
    },
    {
        "country": "AZ",
        "name": "Tovuz",
    },
    {
        "country": "MM",
        "name": "Shan State",
    },
    {
        "country": "CN",
        "name": "Chang'an",
    },
    {
        "country": "CN",
        "name": "Gaochang",
    },
    {
        "country": "CN",
        "name": "Luoyang",
    },
    {
        "country": "CN",
        "name": "Qiuci",
    },
    {
        "country": "CN",
        "name": "Yantai",
    },
    {
        "country": "IN",
        "name": "Nashik",
    },
    {
        "country": "IN",
        "name": "Bangalore",
    },
    {
        "country": "IN",
        "name": "Vijayapura",
    },
    {
        "country": "IN",
        "name": "Narayangaon",
    },
    {
        "country": "IN",
        "name": "Pune",
    },
    {
        "country": "IN",
        "name": "Sangli",
    },
    {
        "country": "IR",
        "name": "Malayer",
    },
    {
        "country": "IR",
        "name": "Takestan",
    },
    {
        "country": "IR",
        "name": "Urmia",
    },
    {
        "country": "IR",
        "name": "Qazvin",
    },
    {
        "country": "IR",
        "name": "Quchan",
    },
    {
        "country": "IL",
        "name": "Galilee",
        "subregions": [
            {
                "name": "Upper Galilee",
            }
        ],
    },
    {
        "country": "IL",
        "name": "Golan Heights",
    },
    {
        "country": "IL",
        "name": "Judean Hills",
        "subregions": [
            {"name": "Jerusalem"},
            {
                "name": "Bet Shemesh",
            }
        ],
    },
    {
        "country": "IL",
        "name": "Mount Carmel",
    },
    {
        "country": "IL",
        "name": "Rishon LeZion",
    },
    {
        "country": "JP",
        "name": "Yamanashi",
    },
    {
        "country": "JP",
        "name": "Hokkaido",
    },
    {
        "country": "JP",
        "name": "Nagano",
    },
    {
        "country": "KR",
        "name": "Anseong",
    },
    {
        "country": "KR",
        "name": "Gimcheon",
    },
    {
        "country": "KR",
        "name": "Gyeongsan",
    },
    {
        "country": "KR",
        "name": "Yeongcheon",
    },
    {
        "country": "KR",
        "name": "Yeongdong",
    },
    {
        "country": "LB",
        "name": "Bekaa Valley",
        "subregions": [
            {"name": "Anjar"},
            {"name": "Chtoura"},
            {"name": "Rashaya"},
            {"name": "Zahlé"},
        ],
    },
    {
        "country": "LB",
        "name": "Mount Lebanon",
        "subregions": [
            {"name": "Aley"},
            {"name": "Baabda"},
            {"name": "Beit Mery"},
            {"name": "Bhamdoun"},
            {"name": "Brummana"},
            {"name": "Byblos"},
            {"name": "Chouf"},
            {"name": "Keserwan District"},
        ],
    },
    {
        "country": "LB",
        "name": "North Governorate",
        "subregions": [
            {"name": "Ehden"},
            {"name": "Koura"},
            {"name": "Qadisha Valley"},
            {"name": "Tripoli"},
            {"name": "Zgharta"},
        ],
    },
    {
        "country": "LB",
        "name": "South Governorate",
        "subregions": [
            {"name": "Jezzine"},
            {"name": "Marjayoun"},
            {"name": "Rmaich"},
        ],
    },
    {
        "country": "PS",
        "name": "Beit Jala",
    },
    {
        "country": "PS",
        "name": "Hebron",
    },
    {
        "country": "SY",
        "name": "Bloudan",
    },
    {
        "country": "SY",
        "name": "Homs District",
    },
    {
        "country": "SY",
        "name": "Jabal el Druze",
    },
    {
        "country": "SY",
        "name": "Latakia",
    },
    {
        "country": "SY",
        "name": "Sednaya",
    },
    {
        "country": "SY",
        "name": "Syrian Golan",
    },
    {
        "country": "SY",
        "name": "Tartous",
    },
    {
        "country": "VN",
        "name": "Da Lat",
    },

    {
        "country": "AU",
        "name": "New South Wales",
        "synonyms": ["NSW"],
        "subregions": [
            {"name": "Big Rivers"},
            {"name": "Canberra District"},
            {"name": "Central Ranges"},
            {"name": "Cowra"},
            {"name": "Griffith"},
            {"name": "Gundagai"},
            {"name": "Hastings River"},
            {"name": "Hawkesbury River"},
            {"name": "Hilltops"},
            {"name": "Hunter Valley"},
            {"name": "Mudgee"},
            {"name": "Murray Darling"},
            {"name": "New England Australia"},
            {"name": "Northern Rivers"},
            {"name": "Northern Slopes"},
            {"name": "Orange"},
            {"name": "Perricoota"},
            {"name": "Riverina"},
            {"name": "Shoalhaven Coast"},
            {"name": "South Coast"},
            {"name": "Southern Highlands"},
            {"name": "Southern New South Wales"},
            {"name": "Swan Hill"},
            {"name": "Tumbarumba"},
            {"name": "Western Plains"}
        ]
    },
    {
        "country": "AU",
        "name": "Northern Territory"
    },
    {
        "country": "AU",
        "name": "Queensland",
        "subregions": [
            {"name": "Granite Belt"},
            {"name": "Scenic Rim"},
            {"name": "South Burnett"}
        ]
    },
    {
        "country": "AU",
        "name": "South Australia",
        "synonyms": ["Southern Australia"],
        "subregions": [
            {"name": "Adelaide Hills"},
            {"name": "Adelaide Plains"},
            {
                "name": "Barossa",
                "subregions": [
                    {"name": "Barossa Valley"},
                    {"name": "Eden Valley"}
                ]
            },
            {
                "name": "Clare Valley", 
                "subregions": [
                    {"name": "Polish Hill River"},
                    {"name": "Watervale"},
                ]
            },
            {"name": "Coonawarra"},
            {"name": "Currency Creek"},
            {"name": "Far North"},
            {"name": "Fleurieu"},
            {"name": "Kangaroo Island"},
            {"name": "Langhorne Creek"},
            {"name": "Lenswood"},
            {"name": "Limestone Coast"},
            {"name": "Lower Murray"},
            {"name": "McLaren Vale"},
            {"name": "Mount Benson"},
            {"name": "Mount Gambier"},
            {"name": "Mount Lofty Ranges"},
            {"name": "Padthaway"},
            {"name": "Piccadilly Valley"},
            {"name": "Riverland"},
            {"name": "Robe"},
            {"name": "Southern Flinders Ranges"},
            {"name": "The Peninsulas"},
            {"name": "Wrattonbully"}
        ]
    },
    {
        "country": "AU",
        "name": "South Eastern Australia",
        "synonyms": ["South East Australia"],
    },
    {
        "country": "AU",
        "name": "Tasmania",
        "subregions": [
            {"name": "Coal River Valley"},
            {"name": "Derwent Valley"},
            {"name": "Huon Valley"},
            {"name": "Pipers River"},
            {"name": "Tamar Valley"}
        ]
    },
    {
        "country": "AU",
        "name": "Victoria",
        "subregions": [
            {"name": "Alpine Valleys"},
            {"name": "Beechworth"},
            {"name": "Bendigo"},
            {"name": "Central Victoria"},
            {
                "name": "Geelong",
                "subregions": [
                    {"name": "Bellarine Peninsula"}
                ]
            },
            {"name": "Gippsland"},
            {"name": "Glenrowan"},
            {"name": "Goulburn Valley"},
            {"name": "Grampians"},
            {"name": "Great Western"},
            {"name": "Heathcote"},
            {"name": "Henty"},
            {"name": "King Valley"},
            {"name": "Macedon Ranges"},
            {"name": "Mornington Peninsula"},
            {"name": "Nagambie Lakes"},
            {"name": "North East Victoria"},
            {"name": "North West Victoria"},
            {"name": "Port Phillip"},
            {"name": "Pyrenees"},
            {"name": "Rutherglen"},
            {"name": "Strathbogie Ranges"},
            {"name": "Sunbury"},
            {"name": "Upper Goulburn"},
            {"name": "Western Victoria"},
            {"name": "Yarra Valley"}
        ]
    },
    {
        "country": "AU",
        "name": "Western Australia",
        "synonyms": ["WA", "West Australia"],
        "subregions": [
            {"name": "Albany"},
            {"name": "Blackwood Valley"},
            {"name": "Denmark Western Australia"},
            {"name": "Ferguson Valley"},
            {"name": "Frankland River"},
            {"name": "Geographe"},
            {"name": "Great Southern"},
            {"name": "Manjimup"},
            {
                "name": "Margaret River",
                "subregions": [
                    {"name": "Karridale"},
                    {"name": "Wallcliffe"},
                    {"name": "Wilyabrup"},
                    {"name": "Yallingup"}
                ]
            },
            {"name": "Mount Barker"},
            {"name": "Peel"},
            {"name": "Pemberton"},
            {"name": "Perth Hills"},
            {"name": "Porongurup"},
            {
                "name": "Swan District",
                "subregions": [
                    {"name": "Swan Valley"}
                ]
            }
        ]
    },
    {
        "country": "NZ",
        "name": "Auckland",
        "subregions": [
            {"name": "Henderson"},
            {"name": "Kumeu"},
            {"name": "Matakana"},
            {
                "name": "Waiheke Island",
                "synonyms": ["Waiheke"],
            },
        ],
    },
    {
        "country": "NZ",
        "name": "Canterbury",
        "subregions": [
            {"name": "North Canterbury"},
            {"name": "Waipara Valley"},
        ],
    },
    {
        "country": "NZ",
        "name": "Central Otago",
        "subregions": [
            {"name": "Bendigo"},
            {"name": "Bannockburn"},
            {"name": "Gibbston"},
            {"name": "Wanaka"},
        ],
    },
    {
        "country": "NZ",
        "name": "Gisborne",
    },
    {
        "country": "NZ",
        "name": "Hawke's Bay",
        "subregions": [
            {"name": "Central Hawke's Bay"},
            {"name": "Gimblett Gravels"},
            {"name": "Bridge Pa Triangle"},
        ],
    },
    {
        "country": "NZ",
        "name": "Marlborough",
        "subregions": [
            {"name": "Wairau Valley"},
            {"name": "Southern Valleys"},
            {"name": "Awatere Valley"},
        ],
    },
    {
        "country": "NZ",
        "name": "Nelson",
    },
    {
        "country": "NZ",
        "name": "Northland",
    },
    {
        "country": "NZ",
        "name": "Waikato",
    },
    {
        "country": "NZ",
        "name": "Wairarapa",
        "subregions": [
            {"name": "Martinborough"},
            {"name": "Gladstone"},
        ],
    },
    {
        "country": "NZ",
        "name": "Waitaki Valley",
    },
]
